@@ -27,6 +27,7 @@
 
 #include <QDateTime>
 #include <QPushButton>
+#include <QPointer>
 
 // KDE includes
 
@@ -190,25 +191,26 @@ void ScanDialog::slotSaveImage(QByteArray &ksane_data, int width, int height, in
     QString defaultFileName("image.png");
     QString format("PNG");
 
-    KFileDialog imageFileSaveDialog(d->interface->currentAlbum().uploadPath(), QString(), 0);
+    QPointer<KFileDialog> imageFileSaveDialog = new KFileDialog(d->interface->currentAlbum().uploadPath(),
+                                                                QString(), 0);
 
-    imageFileSaveDialog.setModal(false);
-    imageFileSaveDialog.setOperationMode(KFileDialog::Saving);
-    imageFileSaveDialog.setMode(KFile::File);
-    imageFileSaveDialog.setSelection(defaultFileName);
-    imageFileSaveDialog.setCaption(i18n("New Image File Name"));
-    imageFileSaveDialog.setMimeFilter(writableMimetypes, defaultMimeType);
+    imageFileSaveDialog->setModal(false);
+    imageFileSaveDialog->setOperationMode(KFileDialog::Saving);
+    imageFileSaveDialog->setMode(KFile::File);
+    imageFileSaveDialog->setSelection(defaultFileName);
+    imageFileSaveDialog->setCaption(i18n("New Image File Name"));
+    imageFileSaveDialog->setMimeFilter(writableMimetypes, defaultMimeType);
 
     // Start dialog and check if canceled.
-    if ( imageFileSaveDialog.exec() != KFileDialog::Accepted )
+    if ( imageFileSaveDialog->exec() != KFileDialog::Accepted )
        return;
 
-    KUrl newURL = imageFileSaveDialog.selectedUrl();
+    KUrl newURL = imageFileSaveDialog->selectedUrl();
     QFileInfo fi(newURL.path());
 
     // Check if target image format have been selected from Combo List of dialog.
 
-    const QStringList mimes = KImageIO::typeForMime(imageFileSaveDialog.currentMimeFilter());
+    const QStringList mimes = KImageIO::typeForMime(imageFileSaveDialog->currentMimeFilter());
     if (!mimes.isEmpty())
     {
         format = mimes.first().toUpper();
@@ -288,17 +290,16 @@ void ScanDialog::slotSaveImage(QByteArray &ksane_data, int width, int height, in
     meta.setImageColorWorkSpace(KExiv2Iface::KExiv2::WORKSPACE_SRGB);
 
     KIPIPlugins::KPWriteImage wImageIface;
-
-    if ( (frmt = KSaneIface::KSaneWidget::FormatRGB_16_C) || (frmt = KSaneIface::KSaneWidget::FormatRGB_8_C) )
-    {
-        // 8 and 16 bits color depth image.
-        wImageIface.setImageData(ksane_data, width, height, true, false, prof, meta);
-    }
-    else
+    if (frmt != KSaneIface::KSaneWidget::FormatRGB_16_C)
     {
         QByteArray data((const char*)img.bits(), img.numBytes());
         wImageIface.setImageData(data, img.width(), img.height(), false, true, prof, meta);
     }
+    else
+    {
+        // 16 bits color depth image.
+        wImageIface.setImageData(ksane_data, width, height, true, false, prof, meta);
+    }
 
     if (format == QString("JPEG"))
     {
@@ -319,6 +320,8 @@ void ScanDialog::slotSaveImage(QByteArray &ksane_data, int width, int height, in
 
     d->interface->refreshImages( KUrl::List(newURL) );
     kapp->restoreOverrideCursor();
+
+    delete imageFileSaveDialog;
 }
 
 }  // namespace KIPIAcquireImagesPlugin
