@@ -7,7 +7,7 @@
  * Description : a kipi plugin to slide images.
  *
  * Copyright (C) 2006-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
  * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  *
  * This program is free software; you can redistribute it
@@ -227,20 +227,20 @@ QMap<QString, QString> SlideShow::effectNamesI18N()
 {
     QMap<QString, QString> effects;
 
-    effects["None"] = i18n( "None" );
-    effects["Chess Board"] = i18n( "Chess Board" );
-    effects["Melt Down"] = i18n( "Melt Down" );
-    effects["Sweep"] = i18n( "Sweep" );
-    effects["Mosaic"] = i18n( "Mosaic" );
-    effects["Cubism"] = i18n( "Cubism" );
-    effects["Growing"] = i18n( "Growing" );
-    effects["Horizontal Lines"] = i18n( "Horizontal Lines" );
-    effects["Vertical Lines"] = i18n( "Vertical Lines" );
-    effects["Circle Out"] = i18n( "Circle Out" );
-    effects["MultiCircle Out"] = i18n( "Multi-Circle Out" );
-    effects["Spiral In"] = i18n( "Spiral In" );
-    effects["Blobs"] = i18n( "Blobs" );
-    effects["Random"] = i18n( "Random" );
+    effects["None"]             = i18nc("Filter Effect: No effect",        "None" );
+    effects["Chess Board"]      = i18nc("Filter Effect: Chess Board",      "Chess Board" );
+    effects["Melt Down"]        = i18nc("Filter Effect: Melt Down",        "Melt Down" );
+    effects["Sweep"]            = i18nc("Filter Effect: Sweep",            "Sweep" );
+    effects["Mosaic"]           = i18nc("Filter Effect: Mosaic",           "Mosaic" );
+    effects["Cubism"]           = i18nc("Filter Effect: Cubism",           "Cubism" );
+    effects["Growing"]          = i18nc("Filter Effect: Growing",          "Growing" );
+    effects["Horizontal Lines"] = i18nc("Filter Effect: Horizontal Lines", "Horizontal Lines" );
+    effects["Vertical Lines"]   = i18nc("Filter Effect: Vertical Lines",   "Vertical Lines" );
+    effects["Circle Out"]       = i18nc("Filter Effect: Circle Out",       "Circle Out" );
+    effects["MultiCircle Out"]  = i18nc("Filter Effect: Multi-Circle Out", "Multi-Circle Out" );
+    effects["Spiral In"]        = i18nc("Filter Effect: Spiral In",        "Spiral In" );
+    effects["Blobs"]            = i18nc("Filter Effect: Blobs",            "Blobs" );
+    effects["Random"]           = i18nc("Filter Effect: Random effect",    "Random" );
 
     return effects;
 }
@@ -411,21 +411,22 @@ void SlideShow::printFilename()
 
 void SlideShow::printComments()
 {
-    if ( m_currImage.isNull() ) return;
+    if (m_currImage.isNull())
+        return;
 
-//    QString comments = m_commentsList[m_fileIndex];
     KIPI::ImageInfo info = m_sharedData->interface->info(m_imageLoader->currPath());
     QString comments = info.description();
 
     int yPos = 30; // Text Y coordinate
 
-    if ( m_sharedData->printFileName ) yPos = 50;
+    if (m_sharedData->printFileName)
+        yPos = 50;
 
     QStringList commentsByLines;
 
     uint commentsIndex = 0; // Comments QString index
 
-    while ( commentsIndex < ( uint ) comments.length() )
+    while (commentsIndex < (uint) comments.length())
     {
         QString newLine;
         bool breakLine = false; // End Of Line found
@@ -435,61 +436,67 @@ void SlideShow::printComments()
 
         uint commentsLinesLengthLocal = m_sharedData->commentsLinesLength;
 
-        for ( currIndex = commentsIndex; currIndex < ( uint ) comments.length() && !breakLine; currIndex++ )
-            if ( comments[currIndex] == QChar( '\n' ) || comments[currIndex].isSpace() ) breakLine = true;
+        for (currIndex = commentsIndex; currIndex < (uint) comments.length() && !breakLine; ++currIndex)
+        {
+            if (comments[currIndex] == QChar('\n') || comments[currIndex].isSpace())
+            {
+                breakLine = true;
+            }
+        }
 
-        if ( commentsLinesLengthLocal <= ( currIndex - commentsIndex ) )
-            commentsLinesLengthLocal = ( currIndex - commentsIndex );
+        if (commentsLinesLengthLocal <= (currIndex - commentsIndex))
+            commentsLinesLengthLocal = (currIndex - commentsIndex);
 
         breakLine = false;
 
-        for ( currIndex = commentsIndex; currIndex <= commentsIndex + commentsLinesLengthLocal &&
-                currIndex < ( uint ) comments.length() &&
-                !breakLine; currIndex++ )
+        for (currIndex = commentsIndex; currIndex <= commentsIndex + commentsLinesLengthLocal &&
+             currIndex < (uint) comments.length() && !breakLine; ++currIndex)
         {
-            breakLine = ( comments[currIndex] == QChar( '\n' ) ) ? true : false;
+            breakLine = (comments[currIndex] == QChar('\n')) ? true : false;
 
-            if ( breakLine )
-                newLine.append( ' ' );
+            if (breakLine)
+                newLine.append(' ');
             else
-                newLine.append( comments[currIndex] );
+                newLine.append(comments[currIndex]);
         }
 
         commentsIndex = currIndex; // The line is ended
 
-        if ( commentsIndex != ( uint ) comments.length() )
-            while ( !newLine.endsWith( " " ) )
+        if (commentsIndex != (uint) comments.length())
+        {
+            while (!newLine.endsWith(' '))
             {
-                newLine.truncate( newLine.length() - 1 );
+                newLine.truncate(newLine.length() - 1);
                 commentsIndex--;
             }
+        }
 
-        commentsByLines.prepend( newLine.trimmed() );
+        commentsByLines.prepend(newLine.trimmed());
     }
 
     QPainter p;
 
-    p.begin( &m_currImage );
-    p.setFont( *m_sharedData->captionFont );
+    p.begin(&m_currImage);
+    p.setFont(*m_sharedData->captionFont);
 
-    for ( int lineNumber = 0; lineNumber < ( int )commentsByLines.count(); lineNumber++ )
+    for (int lineNumber = 0; lineNumber < (int) commentsByLines.count(); lineNumber++)
     {
-
-        p.setPen( QColor( m_sharedData->commentsBgColor ) );
+        p.setPen(QColor(m_sharedData->commentsBgColor));
 
         // coefficient 1.5 is used to maintain distance between different lines
 
-        for ( int x = 9; x <= 11; x++ )
-            for ( int y = ( int )( yPos + lineNumber * 1.5 * m_sharedData->captionFont->pointSize()  + 1 );
-                    y >= ( int )( yPos + lineNumber* 1.5 * m_sharedData->captionFont->pointSize()  - 1 ); y-- )
-                p.drawText( x, height() - y, commentsByLines[lineNumber] );
+        for (int x = 9; x <= 11; x++)
+        {
+            for (int y = (int) (yPos + lineNumber * 1.5 * m_sharedData->captionFont->pointSize() + 1);
+                 y >= (int) (yPos + lineNumber * 1.5 * m_sharedData->captionFont->pointSize() - 1); y--)
+            {
+                p.drawText(x, height() - y, commentsByLines[lineNumber]);
+            }
+        }
 
-        p.setPen( QColor( m_sharedData->commentsFontColor ) );
-
-        p.drawText( 10, height() -
-                    ( int )( lineNumber * 1.5 * m_sharedData->captionFont->pointSize() + yPos ),
-                    commentsByLines[lineNumber]
-                  );
+        p.setPen(QColor(m_sharedData->commentsFontColor));
+        p.drawText(10, height() - (int) (lineNumber * 1.5 * m_sharedData->captionFont->pointSize() + yPos),
+                   commentsByLines[lineNumber]);
     }
 }
 
@@ -501,7 +508,7 @@ void SlideShow::printProgress()
 
     p.begin( &m_currImage );
 
-    QString progress( QString::number( m_fileIndex + 1 ) + "/" + QString::number( m_fileList.count() ) );
+    QString progress( QString::number( m_fileIndex + 1 ) + '/' + QString::number( m_fileList.count() ) );
 
     int stringLength = p.fontMetrics().width( progress ) * progress.length();
 
@@ -719,7 +726,7 @@ int SlideShow::effectMeltdown( bool aInit )
         m_ix = m_w / m_dx;
         m_intArray = new int[m_ix];
 
-        for ( i = m_ix - 1; i >= 0; i-- )
+        for (i = m_ix - 1; i >= 0; --i)
             m_intArray[i] = 0;
     }
 
@@ -738,9 +745,8 @@ int SlideShow::effectMeltdown( bool aInit )
 
         if (( rand()&15 ) < 6 ) continue;
 
-        bufferPainter.drawPixmap( x, y + m_dy, m_buffer, x, y, m_dx, m_h - y - m_dy );
-
-        bufferPainter.drawPixmap( x, y, m_currImage, x, y, m_dx, m_dy );
+        bufferPainter.drawPixmap(x, y + m_dy, m_buffer, x, y, m_dx, m_h - y - m_dy);
+        bufferPainter.drawPixmap(x, y, m_currImage, x, y, m_dx, m_dy);
 
         m_intArray[i] += m_dy;
     }
