@@ -742,8 +742,7 @@ void SlideShowGL::slotTimeOut()
 {
     if (!m_effect)
     {
-        kWarning( 51000 ) << "SlideShowGL: No transition method"
-        << endl;
+        kWarning( 51000 ) << "SlideShowGL: No transition method";
         m_effect = &SlideShowGL::effectNone;
     }
 
