@@ -76,18 +76,22 @@ private:
 
     void addItems(const KUrl::List& fileList);
     void updateTracksNumber();
+    void updateFileList();
     void compareTimes();
 
 private Q_SLOTS:
 
     void slotAddDropItems(KUrl::List filesUrl);
-    void slotSoundFilesButtonAdd( void );
-    void slotSoundFilesButtonDelete( void );
-    void slotSoundFilesButtonUp( void );
-    void slotSoundFilesButtonDown( void );
-    void slotSoundFilesSelected( int );
-    void slotPreviewButtonClicked( void );
-    void slotImageTotalTimeChanged( QTime );
+    void slotSoundFilesButtonAdd();
+    void slotSoundFilesButtonDelete();
+    void slotSoundFilesButtonUp();
+    void slotSoundFilesButtonDown();
+    void slotSoundFilesButtonLoad();
+    void slotSoundFilesButtonSave();
+    void slotSoundFilesButtonReset();
+    void slotSoundFilesSelected(int);
+    void slotPreviewButtonClicked();
+    void slotImageTotalTimeChanged(QTime);
     void slotAddNewTime(KUrl, QTime);
 
 private:
