@@ -37,6 +37,7 @@ extern "C"
 #include <QGroupBox>
 #include <QProgressBar>
 #include <QTimer>
+#include <QPointer>
 
 // KDE includes
 
@@ -71,11 +72,11 @@ namespace KIPIBatchProcessImagesPlugin
 {
 
 BatchProcessImagesDialog::BatchProcessImagesDialog(KUrl::List urlList, KIPI::Interface* interface,
-                                                   QString caption, QWidget *parent)
-                        : KDialog(parent)
-                        , m_listFile2Process_iterator(0)
-                        , m_selectedImageFiles(urlList)
-                        , m_interface(interface)
+        QString caption, QWidget *parent)
+        : KDialog(parent)
+        , m_listFile2Process_iterator(0)
+        , m_selectedImageFiles(urlList)
+        , m_interface(interface)
 {
     setCaption(caption);
     setButtons(Help | User1 | Cancel);
@@ -94,7 +95,7 @@ BatchProcessImagesDialog::BatchProcessImagesDialog(KUrl::List urlList, KIPI::Int
 
     setupUi();
 
-   // Get the image files filters from the hosts app.
+    // Get the image files filters from the hosts app.
 
     m_ImagesFilesSort = m_interface->hostSetting("FileExtensions").toString();
 }
@@ -112,12 +113,12 @@ void BatchProcessImagesDialog::setupUi()
     m_ui->m_optionsButton->setWhatsThis(i18n("You can choose here the options to use for the current process."));
 
     m_ui->m_smallPreview->setWhatsThis(i18n("If you enable this option, "
-                                      "all preview effects will be calculated on a small zone "
-                                      "of the image (300x300 pixels in the top left corner). "
-                                      "Enable this option if you have a slow computer."));
+                                            "all preview effects will be calculated on a small zone "
+                                            "of the image (300x300 pixels in the top left corner). "
+                                            "Enable this option if you have a slow computer."));
 
     m_ui->m_previewButton->setWhatsThis(i18n("This button builds a process "
-                                       "preview for the currently selected image on the list."));
+                                        "preview for the currently selected image on the list."));
 
     m_ui->m_overWriteMode->insertItem(i18n("Ask"));
     m_ui->m_overWriteMode->insertItem(i18n("Always Overwrite"));
@@ -125,28 +126,24 @@ void BatchProcessImagesDialog::setupUi()
     m_ui->m_overWriteMode->insertItem(i18n("Skip"));
     m_ui->m_overWriteMode->setCurrentText(i18n("Rename"));
     m_ui->m_overWriteMode->setWhatsThis(i18n("Select here the overwrite mode used if your target's image "
-                                       "files already exist."));
+                                        "files already exist."));
 
     m_ui->m_removeOriginal->setWhatsThis(i18n("If you enable this option, "
-                                        "all original image files will be removed after processing."));
+                                         "all original image files will be removed after processing."));
 
     m_ui->m_destinationUrl->setMode(KFile::Directory | KFile::LocalOnly);
     KIPI::ImageCollection album = m_interface->currentAlbum();
-    if (album.isValid())
-    {
+    if (album.isValid()) {
         QString url;
-        if (album.isDirectory())
-        {
+        if (album.isDirectory()) {
             url = album.uploadPath().path();
-        }
-        else
-        {
+        } else {
             url = QDir::homePath();
         }
         m_ui->m_destinationUrl->lineEdit()->setText(url);
     }
     m_ui->m_destinationUrl->setWhatsThis(i18n("Here you can select the target folder which "
-                                        "will used by the process."));
+                                         "will used by the process."));
 
     m_ui->m_addImagesButton->setWhatsThis(i18n("Add images to the list."));
     m_ui->m_remImagesButton->setWhatsThis(i18n("Remove selected image from the list."));
@@ -176,11 +173,11 @@ void BatchProcessImagesDialog::setupUi()
     connect(m_Type, SIGNAL(activated(int)),
             this, SLOT(slotTypeChanged(int)));
 
-    connect(m_listFiles, SIGNAL( addedDropItems(QStringList) ),
-            this, SLOT( slotAddDropItems(QStringList)));
+    connect(m_listFiles, SIGNAL(addedDropItems(QStringList)),
+            this, SLOT(slotAddDropItems(QStringList)));
 
-    connect(m_listFiles, SIGNAL( currentItemChanged( QTreeWidgetItem *, QTreeWidgetItem *) ),
-            this, SLOT( slotImageSelected( QTreeWidgetItem * )));
+    connect(m_listFiles, SIGNAL(currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *)),
+            this, SLOT(slotImageSelected(QTreeWidgetItem *)));
 
     connect(m_ui->m_addImagesButton, SIGNAL(clicked()),
             this, SLOT(slotImagesFilesButtonAdd()));
@@ -212,10 +209,9 @@ void BatchProcessImagesDialog::slotImagesFilesButtonAdd(void)
 
 void BatchProcessImagesDialog::slotImagesFilesButtonRem(void)
 {
-    BatchProcessImagesItem *pitem = static_cast<BatchProcessImagesItem*> (m_listFiles->currentItem());
+    BatchProcessImagesItem *pitem = static_cast<BatchProcessImagesItem*>(m_listFiles->currentItem());
 
-    if (pitem)
-    {
+    if (pitem) {
         m_selectedImageFiles.removeOne(pitem->pathSrc());
         delete pitem;
 
@@ -225,13 +221,12 @@ void BatchProcessImagesDialog::slotImagesFilesButtonRem(void)
 
 void BatchProcessImagesDialog::slotImageSelected(QTreeWidgetItem * item)
 {
-    if (!item || m_listFiles->topLevelItemCount() == 0)
-    {
+    if (!item || m_listFiles->topLevelItemCount() == 0) {
         m_ui->m_imageLabel->clear();
         return;
     }
 
-    BatchProcessImagesItem *pitem = static_cast<BatchProcessImagesItem*> (item);
+    BatchProcessImagesItem *pitem = static_cast<BatchProcessImagesItem*>(item);
     if (!pitem)
         return;
 
@@ -253,8 +248,7 @@ void BatchProcessImagesDialog::slotGotPreview(const KFileItem& item, const QPixm
 
     // Rotate the thumbnail compared to the angle the host application dictate
     KIPI::ImageInfo info = m_interface->info(item.url());
-    if (info.angle() != 0)
-    {
+    if (info.angle() != 0) {
         QImage img = pix.convertToImage();
         QMatrix matrix;
 
@@ -271,8 +265,7 @@ void BatchProcessImagesDialog::slotAddDropItems(QStringList filesPath)
     if (filesPath.isEmpty())
         return;
 
-    for (QStringList::Iterator it = filesPath.begin(); it != filesPath.end(); ++it)
-    {
+    for (QStringList::Iterator it = filesPath.begin(); it != filesPath.end(); ++it) {
         QString currentDropFile = *it;
 
         // Check if the new item already exist in the list.
@@ -280,8 +273,7 @@ void BatchProcessImagesDialog::slotAddDropItems(QStringList filesPath)
         bool findItem = false;
 
         for (KUrl::List::Iterator it2 = m_selectedImageFiles.begin();
-             it2 != m_selectedImageFiles.end(); ++it2)
-        {
+                it2 != m_selectedImageFiles.end(); ++it2) {
             QString currentFile = (*it2).path(); // PENDING(blackie) Handle URL's
 
             if (currentFile == currentDropFile)
@@ -300,12 +292,11 @@ void BatchProcessImagesDialog::slotProcessStart(void)
     if (m_selectedImageFiles.isEmpty() == true)
         return;
 
-    if (m_ui->m_removeOriginal->isChecked() == true)
-    {
+    if (m_ui->m_removeOriginal->isChecked() == true) {
         if (KMessageBox::warningContinueCancel(this, i18n(
-                "All original image files will be removed from the source Album.\nDo you want to continue?"),
-                i18n("Delete Original Image Files"), KStandardGuiItem::cont(), KStandardGuiItem::cancel(),
-                "KIPIplugin-BatchProcessImages-AlwaysRemomveOriginalFiles") != KMessageBox::Continue)
+                                                   "All original image files will be removed from the source Album.\nDo you want to continue?"),
+                                               i18n("Delete Original Image Files"), KStandardGuiItem::cont(), KStandardGuiItem::cancel(),
+                                               "KIPIplugin-BatchProcessImages-AlwaysRemomveOriginalFiles") != KMessageBox::Continue)
             return;
     }
 
@@ -320,16 +311,15 @@ void BatchProcessImagesDialog::slotProcessStart(void)
     enableWidgets(false);
     m_ui->m_progress->setVisible(true);
 
-    m_listFile2Process_iterator = new QTreeWidgetItemIterator( m_listFiles );
+    m_listFile2Process_iterator = new QTreeWidgetItemIterator(m_listFiles);
     startProcess();
 }
 
 bool BatchProcessImagesDialog::startProcess(void)
 {
-    if ( m_convertStatus == STOP_PROCESS )
-    {
-       endProcess();
-       return true;
+    if (m_convertStatus == STOP_PROCESS) {
+        endProcess();
+        return true;
     }
 
     QString targetAlbum = m_ui->m_destinationUrl->url().path();
@@ -337,31 +327,27 @@ bool BatchProcessImagesDialog::startProcess(void)
     //TODO check if it is valid also for remote URL's
     // this is a workarond for bug 117397
     QFileInfo dirInfo(targetAlbum + "/");
-    if (!dirInfo.isDir () || !dirInfo.isWritable())
-    {
+    if (!dirInfo.isDir() || !dirInfo.isWritable()) {
         KMessageBox::error(this, i18n("You must specify a writable path for your output file."));
         endProcess();
         return true;
     }
 
-    BatchProcessImagesItem *item = static_cast<BatchProcessImagesItem*>( **m_listFile2Process_iterator );
+    BatchProcessImagesItem *item = static_cast<BatchProcessImagesItem*>(**m_listFile2Process_iterator);
     m_listFiles->setCurrentItem(item);
 
-    if ( prepareStartProcess(item, targetAlbum) == false ) // If there is a problem during the
+    if (prepareStartProcess(item, targetAlbum) == false)   // If there is a problem during the
     {                                                   // preparation -> pass to the next item!
         ++*m_listFile2Process_iterator;
         ++m_progressStatus;
         m_ui->m_progress->setValue((int)((float)m_progressStatus *(float)100 / (float)m_nbItem));
-        item = static_cast<BatchProcessImagesItem*>( **m_listFile2Process_iterator );
+        item = static_cast<BatchProcessImagesItem*>(**m_listFile2Process_iterator);
         m_listFiles->setCurrentItem(item);
 
-        if ( **m_listFile2Process_iterator )
-        {
+        if (**m_listFile2Process_iterator) {
             startProcess();
             return true;
-        }
-        else
-        {
+        } else {
             endProcess();
             return true;
         }
@@ -369,115 +355,92 @@ bool BatchProcessImagesDialog::startProcess(void)
 
     KUrl desturl(targetAlbum + '/' + item->nameDest());
 
-    if ( KIO::NetAccess::exists( desturl, KIO::NetAccess::DestinationSide,
-         kapp->activeWindow() ) == true )
-    {
-       switch (overwriteMode())
-       {
-          case OVERWRITE_ASK:
-          {
-             int ValRet = KMessageBox::warningYesNoCancel(this,
-                          i18n("The destination file \"%1\" already exists;\n"
-                          "do you want overwrite it?", item->nameDest()),
-                          i18n("Overwrite Destination Image File"), KStandardGuiItem::cont());
+    if (KIO::NetAccess::exists(desturl, KIO::NetAccess::DestinationSide,
+                               kapp->activeWindow()) == true) {
+        switch (overwriteMode()) {
+        case OVERWRITE_ASK: {
+            int ValRet = KMessageBox::warningYesNoCancel(this,
+                         i18n("The destination file \"%1\" already exists;\n"
+                              "do you want overwrite it?", item->nameDest()),
+                         i18n("Overwrite Destination Image File"), KStandardGuiItem::cont());
 
-             if ( ValRet == KMessageBox::No )
-             {
+            if (ValRet == KMessageBox::No) {
                 item->changeResult(i18n("Skipped."));
                 item->changeError(i18n("destination image file already exists (skipped by user)."));
                 ++*m_listFile2Process_iterator;
                 ++m_progressStatus;
                 m_ui->m_progress->setValue((int)((float)m_progressStatus *(float)100 / (float)m_nbItem));
 
-                if ( **m_listFile2Process_iterator )
-                {
-                   startProcess();
-                   return true;
+                if (**m_listFile2Process_iterator) {
+                    startProcess();
+                    return true;
+                } else {
+                    endProcess();
+                    return true;
                 }
-                else
-                {
-                   endProcess();
-                   return true;
-                }
-            }
-            else if ( ValRet == KMessageBox::Cancel )
-            {
+            } else if (ValRet == KMessageBox::Cancel) {
                 processAborted(false);
                 return false;
-            }
-            else
-            {
-                item->setDidOverWrite( true );
+            } else {
+                item->setDidOverWrite(true);
             }
 
-             break;
-          }
+            break;
+        }
 
-          case OVERWRITE_RENAME:
-          {
-             QFileInfo Target(targetAlbum + "/" + item->nameDest());
-             QString newFileName = RenameTargetImageFile(&Target);
+        case OVERWRITE_RENAME: {
+            QFileInfo Target(targetAlbum + "/" + item->nameDest());
+            QString newFileName = RenameTargetImageFile(&Target);
 
-             if ( newFileName.isNull() )
-             {
+            if (newFileName.isNull()) {
                 item->changeResult(i18n("Failed."));
                 item->changeError(i18n("destination image file already exists and cannot be renamed."));
                 ++*m_listFile2Process_iterator;
                 ++m_progressStatus;
                 m_ui->m_progress->setValue((int)((float)m_progressStatus *(float)100 / (float)m_nbItem));
 
-                if ( **m_listFile2Process_iterator )
-                {
-                   startProcess();
-                   return true;
+                if (**m_listFile2Process_iterator) {
+                    startProcess();
+                    return true;
+                } else {
+                    endProcess();
+                    return true;
                 }
-                else
-                {
-                   endProcess();
-                   return true;
-                }
-             }
-             else
-             {
+            } else {
                 QFileInfo newTarget(newFileName);
                 item->changeNameDest(newTarget.fileName());
-             }
+            }
 
-             break;
-          }
+            break;
+        }
 
-          case OVERWRITE_SKIP:
-          {
-             item->changeResult(i18n("Skipped."));
-             item->changeError(i18n("destination image file already exists (skipped automatically)."));
-             ++*m_listFile2Process_iterator;
-             ++m_progressStatus;
-             m_ui->m_progress->setValue((int)((float)m_progressStatus *(float)100 / (float)m_nbItem));
+        case OVERWRITE_SKIP: {
+            item->changeResult(i18n("Skipped."));
+            item->changeError(i18n("destination image file already exists (skipped automatically)."));
+            ++*m_listFile2Process_iterator;
+            ++m_progressStatus;
+            m_ui->m_progress->setValue((int)((float)m_progressStatus *(float)100 / (float)m_nbItem));
 
-             if ( **m_listFile2Process_iterator )
-             {
+            if (**m_listFile2Process_iterator) {
                 startProcess();
                 return true;
-             }
-             else
-             {
+            } else {
                 endProcess();
                 return true;
-             }
-             break;
-          }
+            }
+            break;
+        }
 
-          case OVERWRITE_OVER:   // In this case do nothing : 'convert' default mode...
-              item->setDidOverWrite( true );
-             break;
+        case OVERWRITE_OVER:   // In this case do nothing : 'convert' default mode...
+            item->setDidOverWrite(true);
+            break;
 
-          default:
-          {
-             endProcess();
-             return true;
-             break;
-          }
-       }
+        default: {
+            endProcess();
+            return true;
+            break;
+        }
+        }
     }
 
     m_ProcessusProc = new KProcess(this);
@@ -492,12 +455,11 @@ bool BatchProcessImagesDialog::startProcess(void)
     connect(m_ProcessusProc, SIGNAL(readyRead()), SLOT(slotReadyRead()));
 
     m_ProcessusProc->start();
-    if(!m_ProcessusProc->waitForStarted())
-    {
+    if (!m_ProcessusProc->waitForStarted()) {
         KMessageBox::error(this, i18n("Cannot start 'convert' program from 'ImageMagick' package;\n"
                                       "please check your installation."));
         delete m_ProcessusProc;
-        m_ProcessusProc=0;
+        m_ProcessusProc = 0;
         return false;
     }
 
@@ -507,41 +469,36 @@ bool BatchProcessImagesDialog::startProcess(void)
 void BatchProcessImagesDialog::slotReadyRead()
 {
     BatchProcessImagesItem *item =
-            static_cast<BatchProcessImagesItem*> (**m_listFile2Process_iterator);
+        static_cast<BatchProcessImagesItem*>(**m_listFile2Process_iterator);
     QByteArray output = m_ProcessusProc->readAll();
     item->changeOutputMess(QString::fromLocal8Bit(output.data(), output.size()));
 }
 
 void BatchProcessImagesDialog::slotFinished()
 {
-    if (m_convertStatus == PROCESS_DONE)
-    {
+    if (m_convertStatus == PROCESS_DONE) {
         // processAborted() has already been called. No need to show the warning.
         return;
     }
 
     BatchProcessImagesItem *item =
-            static_cast<BatchProcessImagesItem*> (**m_listFile2Process_iterator);
+        static_cast<BatchProcessImagesItem*>(**m_listFile2Process_iterator);
     m_listFiles->scrollToItem(m_listFiles->currentItem());
 
-    if (m_ProcessusProc->exitStatus() == QProcess::CrashExit)
-    {
+    if (m_ProcessusProc->exitStatus() == QProcess::CrashExit) {
         int code = KMessageBox::warningContinueCancel(this,
-                                i18n("The 'convert' program from 'ImageMagick' package has been stopped abnormally"),
-                                i18n("Error running 'convert'"));
+                   i18n("The 'convert' program from 'ImageMagick' package has been stopped abnormally"),
+                   i18n("Error running 'convert'"));
 
-        if (code == KMessageBox::Cancel)
-        {
+        if (code == KMessageBox::Cancel) {
             processAborted(true);
-        }
-        else
-        {
+        } else {
             item->changeResult(i18n("Failed."));
             item->changeError(i18n("'convert' program from 'ImageMagick' package "
                                    "has been stopped abnormally."));
             ++*m_listFile2Process_iterator;
             ++m_progressStatus;
-            m_ui->m_progress->setValue((int) ((float) m_progressStatus * (float) 100 / (float) m_nbItem));
+            m_ui->m_progress->setValue((int)((float) m_progressStatus * (float) 100 / (float) m_nbItem));
 
             if (**m_listFile2Process_iterator)
                 startProcess();
@@ -552,89 +509,77 @@ void BatchProcessImagesDialog::slotFinished()
     }
 
     int ValRet = m_ProcessusProc->exitCode();
-    kWarning() << "Convert exit (" << ValRet << ")" << endl;
+    kWarning() << "Convert exit (" << ValRet << ")";
 
-    switch (ValRet)
-    {
-        case 0:  // Process finished successfully !
-        {
-            item->changeResult(i18n("OK"));
-            item->changeError(i18n("no processing error"));
-            processDone();
+    switch (ValRet) {
+    case 0: { // Process finished successfully !
+        item->changeResult(i18n("OK"));
+        item->changeError(i18n("no processing error"));
+        processDone();
 
-            // Save the comments for the converted image
-            KUrl src;
-            src.setPath(item->pathSrc());
-            KUrl dest = m_ui->m_destinationUrl->url();
-            dest.addPath(item->nameDest());
-            QString errmsg;
+        // Save the comments for the converted image
+        KUrl src;
+        src.setPath(item->pathSrc());
+        KUrl dest = m_ui->m_destinationUrl->url();
+        dest.addPath(item->nameDest());
+        QString errmsg;
 
-            KUrl::List urlList;
-            urlList.append(src);
-            urlList.append(dest);
-            m_interface->refreshImages(urlList);
+        KUrl::List urlList;
+        urlList.append(src);
+        urlList.append(dest);
+        m_interface->refreshImages(urlList);
 
-            if (!item->overWrote())
-            {
-                // Do not add an entry if there was an image at the location already.
-                bool ok = m_interface->addImage(dest, errmsg);
+        if (!item->overWrote()) {
+            // Do not add an entry if there was an image at the location already.
+            bool ok = m_interface->addImage(dest, errmsg);
 
-                if (!ok)
-                {
-                    int code = KMessageBox::warningContinueCancel(this, i18n(
-                            "<qt>Error adding image to application; error message was: "
-                            "<b>%1</b></qt>", errmsg),
-                            i18n("Error Adding Image to Application"));
+            if (!ok) {
+                int code = KMessageBox::warningContinueCancel(this, i18n(
+                               "<qt>Error adding image to application; error message was: "
+                               "<b>%1</b></qt>", errmsg),
+                           i18n("Error Adding Image to Application"));
 
-                    if (code == KMessageBox::Cancel)
-                    {
-                        slotProcessStop();
-                        break;
-                    }
-                    else
-                        item->changeResult(i18n("Failed."));
-                }
+                if (code == KMessageBox::Cancel) {
+                    slotProcessStop();
+                    break;
+                } else
+                    item->changeResult(i18n("Failed."));
             }
-
-            if (src != dest)
-            {
-                KIPI::ImageInfo srcInfo = m_interface->info(src);
-                KIPI::ImageInfo destInfo = m_interface->info(dest);
-                destInfo.cloneData(srcInfo);
-            }
-
-            if (m_ui->m_removeOriginal->isChecked() && src != dest)
-            {
-                KUrl deleteImage(item->pathSrc());
-
-                if (KIO::NetAccess::del(deleteImage, kapp->activeWindow()) == false)
-                {
-                    item->changeResult(i18n("Warning:"));
-                    item->changeError(i18n("cannot remove original image file."));
-                }
-                else
-                    m_interface->delImage(item->pathSrc());
-            }
-            break;
         }
-        case 15: //  process aborted !
-        {
-            processAborted(true);
-            break;
+
+        if (src != dest) {
+            KIPI::ImageInfo srcInfo = m_interface->info(src);
+            KIPI::ImageInfo destInfo = m_interface->info(dest);
+            destInfo.cloneData(srcInfo);
         }
-        default : // Processing error !
-        {
-            item->changeResult(i18n("Failed."));
-            item->changeError(i18n("cannot process original image file."));
-            break;
+
+        if (m_ui->m_removeOriginal->isChecked() && src != dest) {
+            KUrl deleteImage(item->pathSrc());
+
+            if (KIO::NetAccess::del(deleteImage, kapp->activeWindow()) == false) {
+                item->changeResult(i18n("Warning:"));
+                item->changeError(i18n("cannot remove original image file."));
+            } else
+                m_interface->delImage(item->pathSrc());
         }
+        break;
+    }
+    case 15: { //  process aborted !
+        processAborted(true);
+        break;
+    }
+    default : { // Processing error !
+        item->changeResult(i18n("Failed."));
+        item->changeError(i18n("cannot process original image file."));
+        break;
+    }
     }
 
     ++*m_listFile2Process_iterator;
     ++m_progressStatus;
     m_ui->m_progress->setValue((int)((float)m_progressStatus *(float)100 / (float)m_nbItem));
 
-    if ( **m_listFile2Process_iterator )
+    if (**m_listFile2Process_iterator)
         startProcess();
     else
         endProcess();
@@ -642,35 +587,34 @@ void BatchProcessImagesDialog::slotFinished()
 
 void BatchProcessImagesDialog::slotListDoubleClicked(QTreeWidgetItem *itemClicked)
 {
-    BatchProcessImagesItem *item = static_cast<BatchProcessImagesItem*> (itemClicked);
+    BatchProcessImagesItem *item = static_cast<BatchProcessImagesItem*>(itemClicked);
 
-    if (m_convertStatus == PROCESS_DONE)
-    {
-        OutputDialog *infoDialog = new OutputDialog(this, i18n("Image processing error"),
-                                                    item->outputMess(),
-                                                    i18n("Image \"%1\": %2\n\nThe output messages are:\n",
-                                                         item->nameSrc(),
-                                                         item->error()));
+    if (m_convertStatus == PROCESS_DONE) {
+        QPointer<OutputDialog> infoDialog = new OutputDialog(this, i18n("Image processing error"),
+                item->outputMess(),
+                i18n("Image \"%1\": %2\n\nThe output messages are:\n",
+                     item->nameSrc(),
+                     item->error()));
         infoDialog->exec();
+        delete infoDialog;
     }
 }
 
 void BatchProcessImagesDialog::slotPreview(void)
 {
-    kDebug() << "BatchProcessImagesDialog::slotPreview" << endl;
+    kDebug() << "BatchProcessImagesDialog::slotPreview";
 
-    if (m_listFiles->currentItem() == 0)
-    {
+    if (m_listFiles->currentItem() == 0) {
         KMessageBox::error(this, i18n("You must select an item from the list to calculate the preview."));
         return;
     }
 
-    BatchProcessImagesItem *item = static_cast<BatchProcessImagesItem*> (m_listFiles->currentItem());
+    BatchProcessImagesItem *item = static_cast<BatchProcessImagesItem*>(m_listFiles->currentItem());
 
     enableWidgets(false);
 
-    disconnect( this, SIGNAL(user1Clicked()),
-                this, SLOT(slotProcessStart()));
+    disconnect(this, SIGNAL(user1Clicked()),
+               this, SLOT(slotProcessStart()));
 
     showButton(KDialog::Cancel, false);
     setButtonText(User1, i18n("&Stop"));
@@ -685,14 +629,13 @@ void BatchProcessImagesDialog::slotPreview(void)
     m_previewOutput = m_PreviewProc->program().join(" ");
 
     *m_PreviewProc << m_tmpFolder + "/" + QString::number(getpid()) + "preview.PNG";
-    m_previewOutput.append( " "  + m_tmpFolder + "/" + QString::number(getpid()) + "preview.PNG\n\n");
+    m_previewOutput.append(" "  + m_tmpFolder + "/" + QString::number(getpid()) + "preview.PNG\n\n");
 
     connect(m_PreviewProc, SIGNAL(finished(int, QProcess::ExitStatus)), SLOT(slotPreviewFinished()));
     connect(m_PreviewProc, SIGNAL(readyRead()), SLOT(slotPreviewReadyRead()));
 
     m_PreviewProc->start();
-    if(!m_PreviewProc->waitForStarted())
-    {
+    if (!m_PreviewProc->waitForStarted()) {
         KMessageBox::error(this, i18n("Cannot start 'convert' program from 'ImageMagick' package;\n"
                                       "please check your installation."));
         m_ui->m_previewButton->setEnabled(true);
@@ -703,55 +646,46 @@ void BatchProcessImagesDialog::slotPreview(void)
 void BatchProcessImagesDialog::slotPreviewReadyRead()
 {
     QByteArray output = m_PreviewProc->readAll();
-    m_previewOutput.append( QString::fromLocal8Bit(output.data(), output.size()));
+    m_previewOutput.append(QString::fromLocal8Bit(output.data(), output.size()));
 }
 
 void BatchProcessImagesDialog::slotPreviewFinished()
 {
-    if (m_PreviewProc->exitStatus() == QProcess::CrashExit)
-    {
+    if (m_PreviewProc->exitStatus() == QProcess::CrashExit) {
         KMessageBox::error(this, i18n("Cannot run properly 'convert' program from 'ImageMagick' package."));
         m_ui->m_previewButton->setEnabled(true);
         return;
     }
 
-    BatchProcessImagesItem *item = static_cast<BatchProcessImagesItem*>( m_listFiles->currentItem() );
+    BatchProcessImagesItem *item = static_cast<BatchProcessImagesItem*>(m_listFiles->currentItem());
     int ValRet = m_PreviewProc->exitCode();
 
-    kDebug() << "Convert exit (" << ValRet << ")" << endl;
+    kDebug() << "Convert exit (" << ValRet << ")";
 
-    if ( ValRet == 0 )
+    if (ValRet == 0)
     {
-       QString cropTitle = "";
+        QString cropTitle = "";
 
-       if ( m_ui->m_smallPreview->isChecked() )
-          cropTitle = i18n(" - small preview");
+        if (m_ui->m_smallPreview->isChecked())
+            cropTitle = i18n(" - small preview");
 
-       ImagePreview *previewDialog = new ImagePreview(
-                                         item->pathSrc(),
-                                         m_tmpFolder + "/" + QString::number(getpid()) + "preview.PNG",
-                                         m_tmpFolder,
-                                         m_ui->m_smallPreview->isChecked(),
-                                         false,
-                                         m_Type->currentText() + cropTitle,
-                                         item->nameSrc(),
-                                         this);
-       previewDialog->exec();
+        QPointer<ImagePreview> previewDialog = new ImagePreview(item->pathSrc(), m_tmpFolder + "/"
+                + QString::number(getpid()) + "preview.PNG", m_tmpFolder, m_ui->m_smallPreview->isChecked(),
+                false, m_Type->currentText() + cropTitle, item->nameSrc(), this);
+        previewDialog->exec();
+        delete previewDialog;
 
-       KUrl deletePreviewImage(m_tmpFolder + "/" + QString::number(getpid()) + "preview.PNG");
+        KUrl deletePreviewImage(m_tmpFolder + "/" + QString::number(getpid()) + "preview.PNG");
 
-       KIO::NetAccess::del( deletePreviewImage, kapp->activeWindow() );
+        KIO::NetAccess::del(deletePreviewImage, kapp->activeWindow());
     }
     else
     {
-       OutputDialog *infoDialog = new OutputDialog(this,
-                                                   i18n("Preview processing error"),
-                                                   m_previewOutput,
-                                                   i18n("Cannot process preview for image \"%1\"."
-                                                        "\nThe output messages are:\n",
-                                                        item->nameSrc())
-                                                   );
-       infoDialog->exec();
+        QPointer<OutputDialog> infoDialog = new OutputDialog(this, i18n("Preview processing error"),
+                m_previewOutput, i18n("Cannot process preview for image \"%1\"."
+                                      "\nThe output messages are:\n", item->nameSrc()));
+        infoDialog->exec();
+        delete infoDialog;
     }
 
     endPreview();
@@ -767,8 +701,8 @@ void BatchProcessImagesDialog::slotPreviewStop(void)
 void BatchProcessImagesDialog::slotProcessStop(void)
 {
     // Try to kill the current process !
-if (m_ProcessusProc)
-	m_ProcessusProc->close();
+    if (m_ProcessusProc)
+        m_ProcessusProc->close();
 
     // If kill operation failed, Stop the process at the next image !
     if (m_convertStatus == UNDER_PROCESS)
@@ -791,8 +725,7 @@ void BatchProcessImagesDialog::listImageFiles(void)
         return;
 
     for (KUrl::List::Iterator it = m_selectedImageFiles.begin();
-         it != m_selectedImageFiles.end(); ++it)
-    {
+            it != m_selectedImageFiles.end(); ++it) {
         QString currentFile = (*it).path(); // PENDING(blackie) Handle URLS
         QFileInfo *fi = new QFileInfo(currentFile);
 
@@ -802,9 +735,8 @@ void BatchProcessImagesDialog::listImageFiles(void)
 
         QTreeWidgetItemIterator it2(m_listFiles);
 
-        while (*it2)
-        {
-            BatchProcessImagesItem *pitem = static_cast<BatchProcessImagesItem*> (*it2);
+        while (*it2) {
+            BatchProcessImagesItem *pitem = static_cast<BatchProcessImagesItem*>(*it2);
 
             if (pitem->pathSrc() == currentFile.section('/', 0, -1))
                 findItem = true;
@@ -812,25 +744,23 @@ void BatchProcessImagesDialog::listImageFiles(void)
             ++it2;
         }
 
-        if (findItem == false)
-        {
+        if (findItem == false) {
             QString oldFileName = fi->fileName();
             QString newFileName = oldFileName2NewFileName(oldFileName);
 
             new BatchProcessImagesItem(m_listFiles,
-                                        currentFile.section('/', 0, -1),
-                                        oldFileName,
-                                        newFileName,
-                                        ""
-                                        );
+                                       currentFile.section('/', 0, -1),
+                                       oldFileName,
+                                       newFileName,
+                                       ""
+                                      );
         }
 
         delete fi;
     }
 
     QTreeWidgetItem* firstItem = m_listFiles->topLevelItem(0);
-    if (firstItem)
-    {
+    if (firstItem) {
         m_listFiles->setCurrentItem(firstItem);
         slotImageSelected(firstItem);
         m_listFiles->scrollToItem(firstItem);
@@ -876,17 +806,16 @@ int BatchProcessImagesDialog::overwriteMode(void)
 
 void BatchProcessImagesDialog::processAborted(bool removeFlag)
 {
-    kDebug() << "BatchProcessImagesDialog::processAborted" << endl;
+    kDebug() << "BatchProcessImagesDialog::processAborted";
 
     BatchProcessImagesItem *item =
-            static_cast<BatchProcessImagesItem*> (**m_listFile2Process_iterator);
+        static_cast<BatchProcessImagesItem*>(**m_listFile2Process_iterator);
     m_listFiles->scrollToItem(m_listFiles->currentItem());
 
     item->changeResult(i18n("Aborted."));
     item->changeError(i18n("process aborted by user"));
 
-    if (removeFlag == true) // Try to delete de destination !
-    {
+    if (removeFlag == true) { // Try to delete de destination !
         KUrl deleteImage = m_ui->m_destinationUrl->url();
         deleteImage.addPath(item->nameDest());
 
@@ -918,8 +847,7 @@ QString BatchProcessImagesDialog::RenameTargetImageFile(QFileInfo *fi)
     int Enumerator = 0;
     KUrl NewDestUrl;
 
-    do
-    {
+    do {
         ++Enumerator;
         Temp = Temp.setNum(Enumerator);
         NewDestUrl = fi->filePath().left(fi->filePath().findRev('.', -1)) + "_" + Temp + "."
