@@ -57,8 +57,7 @@ class RenameImagesWidget : public QWidget, public Ui_RenameImagesBase
 
 public:
 
-    enum SortOrder
-    {
+    enum SortOrder {
         BYNAME = 0,
         BYSIZE,
         BYDATE
@@ -84,13 +83,13 @@ private:
     bool             m_overwriteAll;
     bool             m_autoSkip;
 
-public slots:
+public Q_SLOTS:
 
     void slotStart();
     void slotAbort();
     void slotNext();
 
-private slots:
+private Q_SLOTS:
 
     void slotListViewDoubleClicked(QTreeWidgetItem*);
     void slotImageSelected(QTreeWidgetItem*);
