@@ -128,6 +128,9 @@ private Q_SLOTS:
 
     void slotItemClicked(QTreeWidgetItem* item, int column);
 
+public:
+    void enableDragAndDrop(const bool enable = true);
+    
 private:
 
     void dragEnterEvent(QDragEnterEvent *e);
@@ -199,6 +202,7 @@ public:
     void               setControlButtons(ControlButtons buttonMask);
     void               setControlButtonsPlacement(ControlButtonPlacement placement);
     void               enableControlButtons(bool enable = true);
+    void               enableDragAndDrop(const bool enable = true);
 
 Q_SIGNALS:
 
@@ -206,20 +210,20 @@ Q_SIGNALS:
     void signalFoundRAWImages(bool);
     void signalItemClicked(QTreeWidgetItem*);
 
-public slots:
+public Q_SLOTS:
 
     virtual void slotAddImages(const KUrl::List& list);
 
 
-protected slots:
+protected Q_SLOTS:
 
     virtual void slotAddItems();
     virtual void slotRemoveItems();
     virtual void slotMoveUpItems();
     virtual void slotMoveDownItems();
     virtual void slotClearItems();
-    virtual void slotLoadItems();
-    virtual void slotSaveItems();
+    virtual void slotLoadItems() {};
+    virtual void slotSaveItems() {};
 
     virtual void slotThumbnail(const KUrl& url, const QPixmap& pix);
     virtual void slotImageListChanged();
