@@ -239,7 +239,7 @@ int DNGWriter::convert()
 
 /*      // NOTE: code to hack RAW data extraction
 
-        QString   rawdataFilePath(inputInfo.baseName() + QString(".dat"));
+        QString   rawdataFilePath(inputInfo.completeBaseName() + QString(".dat"));
         QFileInfo rawdataInfo(rawdataFilePath);
 
         QFile rawdataFile(rawdataFilePath);
@@ -803,17 +803,15 @@ int DNGWriter::convert()
                         &previewList);
 
         // -----------------------------------------------------------------------------------------
-        // Metadata transfert using Exiv2. Used to restore Makernote offset.
+        // Metadata makernote cleanup using Exiv2. See B.K.O #204437.
 
-        kDebug(51000) << "DNGWriter: Backup meta-data using Exiv2" ;
-        KExiv2 dngMeta(dngFilePath);
+        kDebug(51000) << "DNGWriter: cleanup makernotes using Exiv2" ;
 
-        if (meta.load(inputFile()))
+        if (meta.load(dngFilePath))
         {
             meta.setWriteRawFiles(true);
-            meta.setIptc(dngMeta.getIptc());
-            meta.setXmp(dngMeta.getXmp());
-            meta.save(dngFilePath);
+            meta.removeExifTag("Exif.OlympusIp.BlackLevel", false);
+            meta.applyChanges();
         }
     }
 
