@@ -20,11 +20,11 @@
  *
  * ============================================================ */
 
-// KDE includes.
+// KDE includes
 
 #include <kdebug.h>
 
-// Local includes.
+// Local includes
 
 #include "dngwriterhost.h"
 
@@ -44,7 +44,7 @@ void DNGWriterHost::SniffForAbort()
 {
     if (m_priv->cancel)
     {
-        kDebug( 51000 ) << "DNGWriter: Canceled by user..." << endl;
+        kDebug(51000) << "DNGWriter: Canceled by user..." ;
         m_priv->cleanup();
         ThrowUserCanceled();
     }
