@@ -71,7 +71,7 @@ public:
              bool import, QWidget *parent);
     ~FbWindow();
 
-private slots:
+private Q_SLOTS:
 
     void slotBusy(bool val);
     void slotLoginProgress(int step, int maxStep, const QString& label);
