@@ -86,20 +86,35 @@ FlickrTalker::FlickrTalker(QWidget* parent, const QString& serviceName)
     m_photoSetsList = 0;
 
     m_serviceName = serviceName;
-    if (serviceName == "23") 
+    if (serviceName == "23")
     {
         m_apiUrl = QString("http://www.23hq.com/services/rest/");
         m_authUrl = QString("http://www.23hq.com/services/auth/");
         m_uploadUrl = QString("http://www.23hq.com/services/upload/");
+
+        // bshanks: do 23 and flickr really share API keys? or does 23 not need
+        // one?
+        m_apikey = "49d585bafa0758cb5c58ab67198bf632";
+        m_secret = "34b39925e6273ffd";
+    }
+    else if (serviceName == "Zooomr")
+    {
+        m_apiUrl = QString("http://api.zooomr.com/services/rest/");
+        m_authUrl = QString("http://www.zooomr.com/services/auth/");
+        m_uploadUrl = QString("http://upload.zooomr.com/services/upload/");
+
+        m_apikey = "18c8db5ce9ed4e15a7b484136f5080c5";
+        m_secret = "1ea4af14e3";
     }
     else
     {
         m_apiUrl = QString("http://www.flickr.com/services/rest/");
         m_authUrl = QString("http://www.flickr.com/services/auth/");
         m_uploadUrl = QString("http://api.flickr.com/services/upload/");
+
+        m_apikey = "49d585bafa0758cb5c58ab67198bf632";
+        m_secret = "34b39925e6273ffd";
     }
-    m_apikey = "49d585bafa0758cb5c58ab67198bf632";
-    m_secret = "34b39925e6273ffd";
 
     /* Initialize selected photo set as empty. */
     m_selectedPhotoSet = FPhotoSet();
@@ -168,11 +183,22 @@ void FlickrTalker::getFrob()
     url.addQueryItem("api_key", m_apikey);
     QString md5 = getApiSig(m_secret, url);
     url.addQueryItem("api_sig", md5);
-    kDebug(51000) << "Get frob url: " << url << endl;
-    QByteArray tmp;
-    KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
+    kDebug(51000) << "Get frob url: " << url;
+
+    KIO::TransferJob* job;
+    if (m_serviceName == "Zooomr")
+    {
+        // Zooomr redirects the POST at this url to a GET; KIO doesn't follow
+        // the redirect.
+        job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
+    }
+    else
+    {
+        QByteArray tmp;
+        job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
+        job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
+    }
 
-    job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
 
     connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
             this, SLOT(data(KIO::Job*, const QByteArray&)));
@@ -203,11 +229,21 @@ void FlickrTalker::checkToken(const QString& token)
     url.addQueryItem("auth_token", token);
     QString md5 = getApiSig(m_secret, url);
     url.addQueryItem("api_sig", md5);
-    kDebug(51000) << "Check token url: " << url << endl;
+    kDebug(51000) << "Check token url: " << url;
     QByteArray tmp;
-    KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
 
-    job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
+    KIO::TransferJob* job;
+    if (m_serviceName == "Zooomr")
+    {
+        // Zooomr redirects the POST at this url to a GET; KIO doesn't follow the
+        // redirect
+        job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
+   }
+   else
+   {
+        job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
+        job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
+   }
 
     connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
             this, SLOT(data(KIO::Job*, const QByteArray&)));
@@ -238,7 +274,7 @@ void FlickrTalker::slotAuthenticate()
     url.addQueryItem("perms", "write");
     QString md5 = getApiSig(m_secret, url);
     url.addQueryItem("api_sig", md5);
-    kDebug(51000) << "Authenticate url: " << url << endl;
+    kDebug(51000) << "Authenticate url: " << url;
 
     KToolInvocation::invokeBrowser(url.url());
     int valueOk = KMessageBox::questionYesNo(kapp->activeWindow(),
@@ -256,7 +292,7 @@ void FlickrTalker::slotAuthenticate()
     }
     else
     {
-        kDebug(51000) << "User didn't proceed with getToken Authorization, cannot proceed further, aborting" << endl;
+        kDebug(51000) << "User didn't proceed with getToken Authorization, cannot proceed further, aborting";
         cancel();
     }
 }
@@ -275,10 +311,21 @@ void FlickrTalker::getToken()
     url.addQueryItem("frob", m_frob);
     QString md5 = getApiSig(m_secret, url);
     url.addQueryItem("api_sig", md5);
-    kDebug(51000) << "Get token url: " << url << endl;
-    QByteArray tmp;
-    KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
-    job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
+    kDebug(51000) << "Get token url: " << url;
+
+    KIO::TransferJob* job;
+    if (m_serviceName == "Zooomr")
+    {
+        // Zooomr redirects the POST at this url to a GET; KIO doesn't follow
+        // the redirect.
+        job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
+    }
+    else
+    {
+        QByteArray tmp;
+        job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
+        job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
+    }
 
     connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
             this, SLOT(data(KIO::Job*, const QByteArray&)));
@@ -297,7 +344,7 @@ void FlickrTalker::getToken()
 
 void FlickrTalker::listPhotoSets()
 {
-    kDebug(51000) << "List photoset invoked" << endl;
+    kDebug(51000) << "List photoset invoked";
     KUrl url(m_apiUrl);
     url.addQueryItem("auth_token", m_token);
     url.addQueryItem("api_key", m_apikey);
@@ -306,8 +353,18 @@ void FlickrTalker::listPhotoSets()
     url.addQueryItem("api_sig", md5);
     kDebug(51000) << "List photoset URL" << url;
     QByteArray tmp;
-    KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
-    job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );
+    KIO::TransferJob* job;
+    if (m_serviceName == "Zooomr")
+    {
+        // Zooomr redirects the POST at this url to a GET; KIO doesn't follow
+        // the redirect.
+        job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
+    }
+    else
+    {
+        job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
+        job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
+    }
 
     connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
             this, SLOT(data(KIO::Job*, const QByteArray&)));
@@ -342,10 +399,20 @@ void FlickrTalker::getPhotoProperty(const QString& method, const QStringList& ar
 
     QString md5 = getApiSig(m_secret, url);
     url.addQueryItem("api_sig", md5);
-    kDebug(51000) << "Get photo property url: " << url << endl;
+    kDebug(51000) << "Get photo property url: " << url;
     QByteArray tmp;
-    KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
-    job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );
+    KIO::TransferJob* job;
+    if (m_serviceName == "Zooomr")
+    {
+        // Zooomr redirects the POST at this url to a GET; KIO doesn't follow
+        // the redirect.
+        job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
+    }
+    else
+    {
+        job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
+        job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
+    }
 
     connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
             this, SLOT(data(KIO::Job*, const QByteArray&)));
@@ -376,7 +443,7 @@ void FlickrTalker::createPhotoSet(const QString& /*albumName*/, const QString& a
         m_job = 0;
     }
 
-    kDebug(51000) << "create photoset invoked" << endl;
+    kDebug(51000) << "create photoset invoked";
     KUrl url(m_apiUrl);
     url.addQueryItem("auth_token", m_token);
     url.addQueryItem("api_key", m_apikey);
@@ -386,10 +453,22 @@ void FlickrTalker::createPhotoSet(const QString& /*albumName*/, const QString& a
     url.addQueryItem("primary_photo_id", primaryPhotoId);
     QString md5 = getApiSig(m_secret, url);
     url.addQueryItem("api_sig", md5);
-    kDebug(51000) << "List photo sets url: " << url << endl;
+    kDebug(51000) << "List photo sets url: " << url;
     QByteArray tmp;
-    KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
-    job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );
+    KIO::TransferJob* job;
+    if (m_serviceName == "Zooomr")
+    {
+        // Zooomr redirects the POST at this url to a GET; KIO doesn't follow
+        // the redirect (although this function should never get called when
+        // using Zooomr).
+        job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
+    }
+    else
+    {
+        job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
+        job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
+    }
+
 
     connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
             this, SLOT(data(KIO::Job*, const QByteArray&)));
@@ -403,7 +482,8 @@ void FlickrTalker::createPhotoSet(const QString& /*albumName*/, const QString& a
     emit signalBusy(true);
 }
 
-void FlickrTalker::addPhotoToPhotoSet(const QString& photoId,  const QString& photoSetId)
+void FlickrTalker::addPhotoToPhotoSet(const QString& photoId,
+                                      const QString& photoSetId)
 {
     if (m_job)
     {
@@ -411,16 +491,19 @@ void FlickrTalker::addPhotoToPhotoSet(const QString& photoId,  const QString& ph
         m_job = 0;
     }
 
-    kDebug(51000) << "addPhotoToPhotoSet invoked" << endl;
+    kDebug(51000) << "addPhotoToPhotoSet invoked";
     KUrl url(m_apiUrl);
 
     /* If the photoset id starts with the special string "UNDEFINED_", it means
      * it doesn't exist yet on Flickr and needs to be created. Note that it's
      * not necessary to subsequently add the photo to the photo set, as this
      * is done in the set creation call to Flickr. */
-    if (photoSetId.startsWith("UNDEFINED_")) {
+    if (photoSetId.startsWith("UNDEFINED_"))
+    {
         createPhotoSet("", m_selectedPhotoSet.title, m_selectedPhotoSet.description, photoId);
-    } else {
+    }
+    else
+    {
         url.addQueryItem("auth_token", m_token);
 
         url.addQueryItem("photoset_id", photoSetId);
@@ -435,7 +518,7 @@ void FlickrTalker::addPhotoToPhotoSet(const QString& photoId,  const QString& ph
         url.addQueryItem("api_sig", md5);
 
         QByteArray tmp;
-        kDebug(51000) << "Add photo to Photo set url: " << url << endl;
+        kDebug(51000) << "Add photo to Photo set url: " << url;
         KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
         job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
 
@@ -486,6 +569,14 @@ bool FlickrTalker::addPhoto(const QString& photoPath, const FPhotoInfo& info,
     form.addPair("is_friend", isfriend, "text/plain");
     url2.addQueryItem("is_friend", isfriend);
 
+    QString safetyLevel = QString::number(static_cast<int>(info.safety_level));
+    form.addPair("safety_level", safetyLevel, "text/plain");
+    url2.addQueryItem("safety_level", safetyLevel);
+
+    QString contentType = QString::number(static_cast<int>(info.content_type));
+    form.addPair("content_type", contentType, "text/plain");
+    url2.addQueryItem("content_type", contentType);
+
     QString tags = "\"" + info.tags.join("\" \"") + "\"";
     if(tags.length() > 0)
     {
@@ -548,10 +639,10 @@ bool FlickrTalker::addPhoto(const QString& photoPath, const FPhotoInfo& info,
         }
         else
         {
-            kWarning(51000) << "(flickrExport::Image doesn't have metdata)" << endl;
+            kWarning(51000) << "(flickrExport::Image doesn't have metadata)";
         }
 
-        kDebug(51000) << "Resizing and saving to temp file: " << path << endl;
+        kDebug(51000) << "Resizing and saving to temp file: " << path;
     }
 
     if (!form.addFile("photo", path))
@@ -748,22 +839,22 @@ void FlickrTalker::parseResponseGetFrob(const QByteArray& data)
         if (node.isElement() && node.nodeName() == "frob")
         {
             QDomElement e = node.toElement();    // try to convert the node to an element.
-            kDebug(51000) << "Frob is" << e.text() << endl;
+            kDebug(51000) << "Frob is" << e.text();
             m_frob        = e.text();            // this is what is obtained from data.
             success       = true;
         }
 
         if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug(51000) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response";
             errorString = node.toElement().attribute("code");
-            kDebug(51000) << "Error code=" << errorString << endl;
-            kDebug(51000) << "Msg=" << node.toElement().attribute("msg") << endl;
+            kDebug(51000) << "Error code=" << errorString;
+            kDebug(51000) << "Msg=" << node.toElement().attribute("msg");
         }
         node = node.nextSibling();
     }
 
-    kDebug(51000) << "GetFrob finished" << endl;
+    kDebug(51000) << "GetFrob finished";
     m_authProgressDlg->setMaximum(4);
     m_authProgressDlg->setValue(2);
     m_state = FE_GETAUTHORIZED;
@@ -805,17 +896,17 @@ void FlickrTalker::parseResponseCheckToken(const QByteArray& data)
 
                     if(details.nodeName() == "token")
                     {
-                        kDebug(51000) << "Token=" << e.text() << endl;
+                        kDebug(51000) << "Token=" << e.text();
                         m_token = e.text();//this is what is obtained from data.
                     }
 
                     if(details.nodeName() == "perms")
                     {
-                        kDebug(51000) << "Perms=" << e.text() << endl;
+                        kDebug(51000) << "Perms=" << e.text();
                         QString	perms = e.text();//this is what is obtained from data.
 
                         if(perms == "write")
-                            transReturn = i18nc("As in the persmission to", "write");
+                            transReturn = i18nc("As in the permission to", "write");
                         else if(perms == "read")
                             transReturn = i18nc("As in the permission to", "read");
                         else if(perms == "delete")
@@ -824,12 +915,12 @@ void FlickrTalker::parseResponseCheckToken(const QByteArray& data)
 
                     if(details.nodeName() == "user")
                     {
-                        kDebug(51000) << "nsid=" << e.attribute("nsid") << endl;
+                        kDebug(51000) << "nsid=" << e.attribute("nsid");
                         m_userId   = e.attribute("nsid");
                         username   = e.attribute("username");
                         m_username = username;
-                        kDebug(51000) << "username=" << e.attribute("username") << endl;
-                        kDebug(51000) << "fullname=" << e.attribute("fullname") << endl;
+                        kDebug(51000) << "username=" << e.attribute("username");
+                        kDebug(51000) << "fullname=" << e.attribute("fullname");
                     }
                 }
 
@@ -843,10 +934,10 @@ void FlickrTalker::parseResponseCheckToken(const QByteArray& data)
 
         if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug(51000) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response";
             errorString = node.toElement().attribute("code");
-            kDebug(51000) << "Error code=" << errorString << endl;
-            kDebug(51000) << "Msg=" << node.toElement().attribute("msg") << endl;
+            kDebug(51000) << "Error code=" << errorString;
+            kDebug(51000) << "Msg=" << node.toElement().attribute("msg");
 
             int valueOk = KMessageBox::questionYesNo(kapp->activeWindow(),
                                        i18n("Your token is invalid. Would you like to "
@@ -869,7 +960,7 @@ void FlickrTalker::parseResponseCheckToken(const QByteArray& data)
     if(!success)
         emit signalError(errorString);
 
-    kDebug(51000) << "CheckToken finished" << endl;
+    kDebug(51000) << "CheckToken finished";
 }
 
 void FlickrTalker::parseResponseGetToken(const QByteArray& data)
@@ -899,20 +990,20 @@ void FlickrTalker::parseResponseGetToken(const QByteArray& data)
 
                     if(details.nodeName() == "token")
                     {
-                        kDebug(51000) << "Token=" << e.text() << endl;
+                        kDebug(51000) << "Token=" << e.text();
                         m_token = e.text();      //this is what is obtained from data.
                     }
 
                     if(details.nodeName() == "perms")
                     {
-                        kDebug(51000) << "Perms=" << e.text() << endl;
+                        kDebug(51000) << "Perms=" << e.text();
                     }
 
                     if(details.nodeName() == "user")
                     {
-                        kDebug(51000) << "nsid=" << e.attribute("nsid") << endl;
-                        kDebug(51000) << "username=" << e.attribute("username") << endl;
-                        kDebug(51000) << "fullname=" << e.attribute("fullname") << endl;
+                        kDebug(51000) << "nsid=" << e.attribute("nsid");
+                        kDebug(51000) << "username=" << e.attribute("username");
+                        kDebug(51000) << "fullname=" << e.attribute("fullname");
                         m_username = e.attribute("username");
                         m_userId   = e.attribute("nsid");
                     }
@@ -925,17 +1016,17 @@ void FlickrTalker::parseResponseGetToken(const QByteArray& data)
         }
         else if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug(51000) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response";
             errorString = node.toElement().attribute("code");
-            kDebug(51000) << "Error code=" << errorString << endl;
-            kDebug(51000) << "Msg=" << node.toElement().attribute("msg") << endl;
+            kDebug(51000) << "Error code=" << errorString;
+            kDebug(51000) << "Msg=" << node.toElement().attribute("msg");
             //emit signalError(code);
         }
 
         node = node.nextSibling();
     }
 
-    kDebug(51000) << "GetToken finished" << endl;
+    kDebug(51000) << "GetToken finished";
     //emit signalBusy( false );
     m_authProgressDlg->hide();
 
@@ -947,7 +1038,7 @@ void FlickrTalker::parseResponseGetToken(const QByteArray& data)
 
 void FlickrTalker::parseResponseCreatePhotoSet(const QByteArray& data)
 {
-    kDebug(51000) << "Parse response create photoset recieved " << data << endl;
+    kDebug(51000) << "Parse response create photoset received " << data;
 
     //bool success = false;
 
@@ -963,32 +1054,34 @@ void FlickrTalker::parseResponseCreatePhotoSet(const QByteArray& data)
     {
         if (node.isElement() && node.nodeName() == "photoset")
         {
-          // Parse the id from the response.
-          QString new_id = node.toElement().attribute("id");
+            // Parse the id from the response.
+            QString new_id = node.toElement().attribute("id");
 
-          // Set the new id in the photo sets list.
-          QLinkedList<FPhotoSet>::iterator it = m_photoSetsList->begin();
-          while(it != m_photoSetsList->end()) {
-            if (it->id == m_selectedPhotoSet.id) {
-              it->id = new_id;
-              break;
+            // Set the new id in the photo sets list.
+            QLinkedList<FPhotoSet>::iterator it = m_photoSetsList->begin();
+            while(it != m_photoSetsList->end())
+            {
+                if (it->id == m_selectedPhotoSet.id)
+                {
+                    it->id = new_id;
+                    break;
+                }
+                it++;
             }
-            it++;
-          }
-          // Set the new id in the selected photo set.
-          m_selectedPhotoSet.id = new_id;
+            // Set the new id in the selected photo set.
+            m_selectedPhotoSet.id = new_id;
 
-          kDebug() << "PhotoSet created successfully with id" << new_id << endl;
-          emit signalAddPhotoSetSucceeded();
+            kDebug() << "PhotoSet created successfully with id" << new_id;
+            emit signalAddPhotoSetSucceeded();
         }
 
         if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug(51000) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response";
             QString code = node.toElement().attribute("code");
-            kDebug(51000) << "Error code=" << code << endl;
+            kDebug(51000) << "Error code=" << code;
             QString msg = node.toElement().attribute("msg");
-            kDebug(51000) << "Msg=" << msg << endl;
+            kDebug(51000) << "Msg=" << msg;
             KMessageBox::error(kapp->activeWindow(), i18n("PhotoSet creation failed: ") + msg);
         }
 
@@ -998,7 +1091,7 @@ void FlickrTalker::parseResponseCreatePhotoSet(const QByteArray& data)
 
 void FlickrTalker::parseResponseListPhotoSets(const QByteArray& data)
 {
-    kDebug(51000) << "parseResponseListPhotosets" << data << endl;
+    kDebug(51000) << "parseResponseListPhotosets" << data;
     bool success = false;
     QDomDocument doc("getListPhotoSets");
     if (!doc.setContent(data))
@@ -1026,7 +1119,7 @@ void FlickrTalker::parseResponseListPhotoSets(const QByteArray& data)
                     e = detailsNode.toElement();
                     if(detailsNode.nodeName() == "photoset")
                     {
-                        kDebug(51000) << "id=" << e.attribute("id") << endl;
+                        kDebug(51000) << "id=" << e.attribute("id");
                         photoSet_id              = e.attribute("id");     // this is what is obtained from data.
                         fps.id                   = photoSet_id;
                         QDomNode photoSetDetails = detailsNode.firstChild();
@@ -1038,13 +1131,13 @@ void FlickrTalker::parseResponseListPhotoSets(const QByteArray& data)
 
                             if(photoSetDetails.nodeName() == "title")
                             {
-                                kDebug(51000) << "Title=" << e_detail.text() << endl;
+                                kDebug(51000) << "Title=" << e_detail.text();
                                 photoSet_title = e_detail.text();
                                 fps.title      = photoSet_title;
                             }
                             else if(photoSetDetails.nodeName() == "description")
                             {
-                                kDebug(51000) << "Description =" << e_detail.text() << endl;
+                                kDebug(51000) << "Description =" << e_detail.text();
                                 photoSet_description = e_detail.text();
                                 fps.description      = photoSet_description;
                             }
@@ -1065,17 +1158,17 @@ void FlickrTalker::parseResponseListPhotoSets(const QByteArray& data)
 
         if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug(51000) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response";
             QString code = node.toElement().attribute("code");
-            kDebug(51000) << "Error code=" << code << endl;
-            kDebug(51000) << "Msg=" << node.toElement().attribute("msg") << endl;
+            kDebug(51000) << "Error code=" << code;
+            kDebug(51000) << "Msg=" << node.toElement().attribute("msg");
             emit signalError(code);
         }
 
         node = node.nextSibling();
     }
 
-    kDebug(51000) << "GetPhotoList finished" << endl;
+    kDebug(51000) << "GetPhotoList finished";
 
     if (!success)
     {
@@ -1131,16 +1224,16 @@ void FlickrTalker::parseResponseAddPhoto(const QByteArray& data)
             e                = node.toElement();           // try to convert the node to an element.
             QDomNode details = e.firstChild();
             photoId = e.text();
-            kDebug(51000) << "Photoid= " << photoId << endl;
+            kDebug(51000) << "Photoid= " << photoId;
             success = true;
         }
 
         if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug(51000) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response";
             QString code = node.toElement().attribute("code");
-            kDebug(51000) << "Error code=" << code << endl;
-            kDebug(51000) << "Msg=" << node.toElement().attribute("msg") << endl;
+            kDebug(51000) << "Error code=" << code;
+            kDebug(51000) << "Msg=" << node.toElement().attribute("msg");
             emit signalError(code);
         }
 
@@ -1161,7 +1254,16 @@ void FlickrTalker::parseResponseAddPhoto(const QByteArray& data)
         }
         else
         {
-            addPhotoToPhotoSet(photoId, photoSetId);
+            if (m_serviceName == "Zooomr")
+            {
+                // addPhotoToPhotoSet not supported by Zooomr (Zooomr only has
+                // smart folder-type photosets); silently fail
+                emit signalAddPhotoSucceeded();
+            }
+            else
+            {
+                addPhotoToPhotoSet(photoId, photoSetId);
+            }
         }
     }
 }
@@ -1184,23 +1286,23 @@ void FlickrTalker::parseResponsePhotoProperty(const QByteArray& data)
         {
             e = node.toElement();                 // try to convert the node to an element.
             QDomNode details = e.firstChild();
-            kDebug(51000) << "Photoid=" << e.text() << endl;
+            kDebug(51000) << "Photoid=" << e.text();
             success = true;
         }
 
         if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug(51000) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response";
             QString code = node.toElement().attribute("code");
-            kDebug(51000) << "Error code=" << code << endl;
-            kDebug(51000) << "Msg=" << node.toElement().attribute("msg") << endl;
+            kDebug(51000) << "Error code=" << code;
+            kDebug(51000) << "Msg=" << node.toElement().attribute("msg");
             emit signalError(code);
         }
 
         node = node.nextSibling();
     }
 
-    kDebug(51000) << "GetToken finished" << endl;
+    kDebug(51000) << "GetToken finished";
 
     if (!success)
     {
@@ -1214,7 +1316,7 @@ void FlickrTalker::parseResponsePhotoProperty(const QByteArray& data)
 
 void FlickrTalker::parseResponseAddPhotoToPhotoSet(const QByteArray& data)
 {
-    kDebug(51000) << "parseResponseListPhotosets" << data << endl;
+    kDebug(51000) << "parseResponseListPhotosets" << data;
     emit signalAddPhotoSucceeded();
 }
 
