@@ -34,6 +34,7 @@
 #include <QCheckBox>
 #include <QStringList>
 #include <QSpinBox>
+#include <QPointer>
 
 // KDE includes
 
@@ -68,6 +69,7 @@
 #include "login.h"
 #include "flickrtalker.h"
 #include "flickritem.h"
+#include "flickrlist.h"
 //#include "flickrviewitem.h"
 #include "flickrwidget.h"
 #include "ui_flickralbumdialog.h"
@@ -80,7 +82,7 @@ FlickrWindow::FlickrWindow(KIPI::Interface* interface, const QString &tmpFolder,
 {
     m_serviceName = serviceName;
     setWindowTitle(i18n("Export to %1 Web Service", m_serviceName));
-    if (serviceName != "23")
+    if ((serviceName != "23") && (serviceName != "Zooomr"))
         setWindowIcon(KIcon("flickr"));
     setButtons(Help|User1|Close);
     setDefaultButton(Close);
@@ -101,6 +103,9 @@ FlickrWindow::FlickrWindow(KIPI::Interface* interface, const QString &tmpFolder,
     m_friendsCheckBox        = m_widget->m_friendsCheckBox;
     m_dimensionSpinBox       = m_widget->m_dimensionSpinBox;
     m_imageQualitySpinBox    = m_widget->m_imageQualitySpinBox;
+    m_extendedButton         = m_widget->m_extendedButton;
+    m_safetyLevelComboBox    = m_widget->m_safetyLevelComboBox;
+    m_contentTypeComboBox    = m_widget->m_contentTypeComboBox;
     m_tagsLineEdit           = m_widget->m_tagsLineEdit;
     m_exportHostTagsCheckBox = m_widget->m_exportHostTagsCheckBox;
     m_stripSpaceTagsCheckBox = m_widget->m_stripSpaceTagsCheckBox;
@@ -120,11 +125,11 @@ FlickrWindow::FlickrWindow(KIPI::Interface* interface, const QString &tmpFolder,
     // --------------------------------------------------------------------------
     // About data and help button.
 
-    m_about = new KIPIPlugins::KPAboutData(ki18n("Flickr/23 Export"),
+    m_about = new KIPIPlugins::KPAboutData(ki18n("Flickr/23/Zooomr Export"),
                                            0,
                                            KAboutData::License_GPL,
                                            ki18n("A Kipi plugin to export image collection to "
-                                                     "Flickr / 23 web service."),
+                                                     "Flickr / 23 / Zooomr web service."),
                                            ki18n( "(c) 2005-2008, Vardhman Jain\n"
                                            "(c) 2008, Gilles Caulier\n"
                                            "(c) 2009, Luka Renko" ));
@@ -220,7 +225,7 @@ FlickrWindow::FlickrWindow(KIPI::Interface* interface, const QString &tmpFolder,
     m_talker->m_authProgressDlg = m_authProgressDlg;
     m_widget->setEnabled(false);
 
-    kDebug(51000) << "Calling auth methods" << endl;
+    kDebug(51000) << "Calling auth methods";
 
     if(m_token.length()< 1)
         m_talker->getFrob();
@@ -280,6 +285,17 @@ void FlickrWindow::readSettings()
     m_publicCheckBox->setChecked(grp.readEntry("Public Sharing", false));
     m_familyCheckBox->setChecked(grp.readEntry("Family Sharing", false));
     m_friendsCheckBox->setChecked(grp.readEntry("Friends Sharing", false));
+
+    m_extendedButton->setChecked(grp.readEntry("Show Extended Options", false));
+    int safetyLevel = m_safetyLevelComboBox->findData(
+                          QVariant(grp.readEntry("Safety Level", 0)));
+    if (safetyLevel == -1) safetyLevel = 0;
+    m_safetyLevelComboBox->setCurrentIndex(safetyLevel);
+    int contentType = m_contentTypeComboBox->findData(
+                          QVariant(grp.readEntry("Content Type", 0)));
+    if (contentType == -1) contentType = 0;
+    m_contentTypeComboBox->setCurrentIndex(contentType);
+
     KConfigGroup dialogGroup = config.group(QString("%1Export Dialog").arg(m_serviceName));
     restoreDialogSize(dialogGroup);
 }
@@ -297,6 +313,11 @@ void FlickrWindow::writeSettings()
     grp.writeEntry("Public Sharing", m_publicCheckBox->isChecked());
     grp.writeEntry("Family Sharing", m_familyCheckBox->isChecked());
     grp.writeEntry("Friends Sharing", m_friendsCheckBox->isChecked());
+    grp.writeEntry("Show Extended Options", m_extendedButton->isChecked());
+    int safetyLevel = m_safetyLevelComboBox->itemData(m_safetyLevelComboBox->currentIndex()).toInt();
+    grp.writeEntry("Safety Level", safetyLevel);
+    int contentType = m_contentTypeComboBox->itemData(m_contentTypeComboBox->currentIndex()).toInt();
+    grp.writeEntry("Content Type", contentType);
     KConfigGroup dialogGroup = config.group(QString("%1Export Dialog").arg(m_serviceName));
     saveDialogSize(dialogGroup );
     config.sync();
@@ -322,9 +343,15 @@ void FlickrWindow::slotTokenObtained(const QString& token)
     m_token    = token;
     m_username = m_talker->getUserName();
     m_userId   = m_talker->getUserId();
-    kDebug(51000) << "SlotTokenObtained invoked setting user Display name to " << m_username << endl;
+    kDebug(51000) << "SlotTokenObtained invoked setting user Display name to " << m_username;
     m_userNameDisplayLabel->setText(QString("<b>%1</b>").arg(m_username));
-    m_talker->listPhotoSets();
+    if (m_serviceName != "Zooomr")
+        m_talker->listPhotoSets();
+    else
+        // Mutable photosets are not supported by Zooomr (Zooomr only has smart
+        // folder-type photosets). So we're done and can active the Flickr
+        // widget.
+        m_widget->setEnabled(true);
 }
 
 void FlickrWindow::slotBusy(bool val)
@@ -351,7 +378,7 @@ void FlickrWindow::slotError(const QString& msg)
 
 void FlickrWindow::slotUserChangeRequest()
 {
-    kDebug(51000) << "Slot Change User Request " << endl;
+    kDebug(51000) << "Slot Change User Request ";
     m_talker->getFrob();
 //  m_addPhotoButton->setEnabled(m_selectImagesButton->isChecked());
 }
@@ -365,7 +392,7 @@ void FlickrWindow::slotCreateNewPhotoSet()
     * Flickr yet. */
 
    // Call the dialog
-   FlickrNewPhotoSetDialog *dlg = new FlickrNewPhotoSetDialog(kapp->activeWindow());
+   QPointer<FlickrNewPhotoSetDialog> dlg = new FlickrNewPhotoSetDialog(kapp->activeWindow());
    int resp = dlg->exec();
    if ((resp == QDialog::Accepted) && (dlg->titleEdit->text() != ""))
    {
@@ -379,28 +406,32 @@ void FlickrWindow::slotCreateNewPhotoSet()
       int i = 0;
       id = "UNDEFINED_" + QString::number(i);
       QLinkedList<FPhotoSet>::iterator it = m_talker->m_photoSetsList->begin();
-      while(it != m_talker->m_photoSetsList->end()) {
-        FPhotoSet fps = *it;
-        if (fps.id == id) {
-          id = "UNDEFINED_" + QString::number(++i);
-          it = m_talker->m_photoSetsList->begin();
-        }
-        it++;
+      while(it != m_talker->m_photoSetsList->end())
+      {
+          FPhotoSet fps = *it;
+          if (fps.id == id)
+          {
+              id = "UNDEFINED_" + QString::number(++i);
+              it = m_talker->m_photoSetsList->begin();
+          }
+          it++;
       }
       fps.id = id;
 
-      kDebug() << "Created new photoset with temporary id " << id << endl;
+      kDebug() << "Created new photoset with temporary id " << id;
       // Append the new photoset to the list.
       m_talker->m_photoSetsList->prepend(fps);
       m_talker->m_selectedPhotoSet = fps;
 
-      // Repopulate the photo sets combo box.
+      // Re-populate the photo sets combo box.
       populatePhotoSetComboBox();
    }
    else
    {
-     kDebug(51000) << "New Photoset creation aborted " << endl;
+       kDebug(51000) << "New Photoset creation aborted ";
    }
+
+   delete dlg;
 }
 
 void FlickrWindow::slotAuthCancel()
@@ -427,7 +458,7 @@ void FlickrWindow::slotOpenPhoto( const KUrl& url )
 
 void FlickrWindow::populatePhotoSetComboBox()
 {
-    kDebug(51000) << "populatePhotoSetComboBox invoked" << endl;
+    kDebug(51000) << "populatePhotoSetComboBox invoked";
     if (m_talker && m_talker->m_photoSetsList)
     {
         QLinkedList <FPhotoSet> *list = m_talker->m_photoSetsList;
@@ -457,29 +488,33 @@ void FlickrWindow::populatePhotoSetComboBox()
 */
 void FlickrWindow::slotUser1()
 {
-    kDebug(51000) << "SlotUploadImages invoked" << endl;
+    kDebug(51000) << "SlotUploadImages invoked";
 
     m_widget->m_tab->setCurrentIndex(FlickrWidget::FILELIST);
-    KUrl::List urls = m_imglst->imageUrls();
 
-    if (urls.isEmpty())
+    if (m_imglst->imageUrls().isEmpty())
         return;
 
     typedef QPair<KUrl, FPhotoInfo> Pair;
 
     m_uploadQueue.clear();
 
-    for (KUrl::List::iterator it = urls.begin(); it != urls.end(); ++it)
+    for (int i = 0; i < m_imglst->listView()->topLevelItemCount(); ++i)
     {
-        KIPI::ImageInfo info = m_interface->info(*it);
-        kDebug(51000) << "Adding images to the list" << endl;
+        FlickrListViewItem *lvItem = dynamic_cast<FlickrListViewItem*>
+                                     (m_imglst->listView()->topLevelItem(i));
+
+        KIPI::ImageInfo info = m_interface->info(lvItem->url());
+        kDebug(51000) << "Adding images to the list";
         FPhotoInfo temp;
 
         temp.title                 = info.title();
         temp.description           = info.description();
-        temp.is_public             = m_publicCheckBox->isChecked();
-        temp.is_family             = m_familyCheckBox->isChecked();
-        temp.is_friend             = m_friendsCheckBox->isChecked();
+        temp.is_public             = lvItem->isPublic()  ? 1 : 0;
+        temp.is_family             = lvItem->isFamily()  ? 1 : 0;
+        temp.is_friend             = lvItem->isFriends() ? 1 : 0;
+        temp.safety_level          = lvItem->safetyLevel();
+        temp.content_type          = lvItem->contentType();
         QStringList tagsFromDialog = m_tagsLineEdit->text().split(" ", QString::SkipEmptyParts);
 
         QStringList           allTags;
@@ -519,19 +554,19 @@ void FlickrWindow::slotUser1()
 
         while(itTags != allTags.end())
         {
-            kDebug(51000) << "Tags list: " << (*itTags) << endl;
+            kDebug(51000) << "Tags list: " << (*itTags);
             ++itTags;
         }
 
         temp.tags = allTags;
-        m_uploadQueue.append(Pair(*it, temp));
+        m_uploadQueue.append(Pair(lvItem->url(), temp));
     }
 
     m_uploadTotal = m_uploadQueue.count();
     m_uploadCount = 0;
     m_progressDlg->reset();
     slotAddPhotoNext();
-    kDebug(51000) << "SlotUploadImages done" << endl;
+    kDebug(51000) << "SlotUploadImages done";
 }
 
 void FlickrWindow::slotAddPhotoNext()
@@ -549,25 +584,34 @@ void FlickrWindow::slotAddPhotoNext()
     FPhotoInfo info   = pathComments.second;
 
     // Find out the selected photo set.
-    QString selectedPhotoSetId = m_albumsListComboBox->itemData(m_albumsListComboBox->currentIndex()).toString();
-    if (selectedPhotoSetId == "") {
-       m_talker->m_selectedPhotoSet = FPhotoSet();
-    } else {
-       QLinkedList<FPhotoSet>::iterator it = m_talker->m_photoSetsList->begin();
-       while(it != m_talker->m_photoSetsList->end()) {
-          if (it->id == selectedPhotoSetId) {
-             m_talker->m_selectedPhotoSet = *it;
-             break;
-          }
-          it++;
-       }
+    if (m_serviceName != "Zooomr")
+    {
+        // mutable photosets are not supported by Zooomr (Zooomr only has smart folder-type photosets)
+        QString selectedPhotoSetId = m_albumsListComboBox->itemData(m_albumsListComboBox->currentIndex()).toString();
+        if (selectedPhotoSetId == "")
+        {
+           m_talker->m_selectedPhotoSet = FPhotoSet();
+        }
+        else
+        {
+            QLinkedList<FPhotoSet>::iterator it = m_talker->m_photoSetsList->begin();
+            while(it != m_talker->m_photoSetsList->end())
+            {
+                if (it->id == selectedPhotoSetId)
+                {
+                    m_talker->m_selectedPhotoSet = *it;
+                    break;
+                }
+                it++;
+            }
+        }
     }
 
-    bool res          = m_talker->addPhoto(pathComments.first.path(), //the file path
-                       info,
-                                           m_resizeCheckBox->isChecked(),
-                                           m_dimensionSpinBox->value(),
-                                           m_imageQualitySpinBox->value()
+    bool res = m_talker->addPhoto(pathComments.first.path(), //the file path
+                                  info,
+                                  m_resizeCheckBox->isChecked(),
+                                  m_dimensionSpinBox->value(),
+                                  m_imageQualitySpinBox->value()
                        );
     if (!res)
     {
@@ -592,7 +636,8 @@ void FlickrWindow::slotAddPhotoSucceeded()
     slotAddPhotoNext();
 }
 
-void FlickrWindow::slotListPhotoSetsFailed(const QString& msg) {
+void FlickrWindow::slotListPhotoSetsFailed(const QString& msg)
+{
     KMessageBox::error(this,
                  i18n("Failed to Fetch Photoset information from %1. %2\n", m_serviceName, msg));
 }
@@ -620,7 +665,7 @@ void FlickrWindow::slotAddPhotoFailed(const QString& msg)
 
 void FlickrWindow::slotAddPhotoSetSucceeded()
 {
-  /* Method called when a photo set has been succesfully created on Flickr.
+  /* Method called when a photo set has been successfully created on Flickr.
    * It functions to restart the normal flow after a photo set has been created
    * on Flickr. */
   populatePhotoSetComboBox();
