@@ -35,6 +35,10 @@
 
 #include <kdialog.h>
 
+// Local includes
+
+#include "comboboxintermediate.h"
+
 // LibKIPI includes
 
 #include <libkipi/interface.h>
@@ -57,7 +61,7 @@ class Interface;
 namespace KIPIPlugins
 {
 class KPAboutData;
-class ImagesList;
+class FlickrList;
 }
 
 namespace KWallet
@@ -74,7 +78,7 @@ class FPhotoInfo;
 class GPhoto;
 class GAlbum;
 //class GAlbumViewItem;
-class ImagesList;
+class FlickrList;
 
 class FlickrWindow : public KDialog
 {
@@ -86,7 +90,7 @@ public:
                  QWidget *parent, const QString& serviceName);
     ~FlickrWindow();
 
-private slots:
+private Q_SLOTS:
 
     void slotTokenObtained(const QString& token);
     void slotDoLogin();
@@ -140,6 +144,10 @@ private:
     QSpinBox                              *m_dimensionSpinBox;
     QSpinBox                              *m_imageQualitySpinBox;
 
+    QPushButton                           *m_extendedButton;
+    ComboBoxIntermediate                  *m_contentTypeComboBox;
+    ComboBoxIntermediate                  *m_safetyLevelComboBox;
+
 //    QHash<int, GAlbumViewItem>             m_albumDict;
 
     QString                                m_token;
@@ -166,7 +174,7 @@ private:
     KIPI::Interface                       *m_interface;
 
     KIPIPlugins::KPAboutData              *m_about;
-    KIPIPlugins::ImagesList               *m_imglst;
+    KIPIFlickrExportPlugin::FlickrList    *m_imglst;
 };
 
 } // namespace KIPIFlickrExportPlugin
