@@ -51,15 +51,17 @@ public:
     virtual KIPI::Category category(KAction* action) const;
     virtual void setup(QWidget*);
 
-public slots:
+public Q_SLOTS:
 
     void slotActivate();
     void slotActivate23();
+    void slotActivateZooomr();
 
 private:
 
-    KAction                                 *m_action;
+    KAction                                 *m_actionFlickr;
     KAction                                 *m_action23;
+    KAction                                 *m_actionZooomr;
     KIPIFlickrExportPlugin::FlickrWindow    *m_dlg;
 };
 
