@@ -26,6 +26,10 @@
 #include "plugin_galleryexport.h"
 #include "plugin_galleryexport.moc"
 
+// Qt includes
+
+#include <QPointer>
+
 // KDE includes
 
 #include <kaction.h>
@@ -55,21 +59,21 @@ Plugin_GalleryExport::Plugin_GalleryExport(QObject *parent, const QVariantList&)
                     : KIPI::Plugin(Factory::componentData(), parent, "GalleryExport"),
                       m_action(0), mpGallery(0)
 {
-    kDebug(51001) << "Plugin_GalleryExport plugin loaded"
-                  << endl;
+    kDebug(51001) << "Plugin_GalleryExport plugin loaded";
 }
 
 void Plugin_GalleryExport::setup(QWidget* widget)
 {
+    KIconLoader::global()->addAppDir("kipiplugin_galleryexport");
+
     mpGallery = new KIPIGalleryExportPlugin::Gallery();
 
     KIPI::Plugin::setup(widget);
 
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
-
     if (!interface)
     {
-        kError(51000) << "Kipi interface is null!" << endl;
+        kError(51000) << "Kipi interface is null!";
         return;
     }
 
@@ -85,7 +89,6 @@ void Plugin_GalleryExport::setup(QWidget* widget)
     addAction(m_action);
 }
 
-
 Plugin_GalleryExport::~Plugin_GalleryExport()
 {
     if (mpGallery)
@@ -98,18 +101,26 @@ void Plugin_GalleryExport::slotSync()
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
     if (!interface)
     {
-        kError(51000) << "Kipi interface is null!" << endl;
+        kError(51000) << "Kipi interface is null!";
         return;
     }
 
+    QPointer<KIPIGalleryExportPlugin::GalleryEdit>   configDlg;
+    QPointer<KIPIGalleryExportPlugin::GalleryWindow> dlg;
+
     KConfig config("kipirc");
     if(!config.hasGroup("Gallery Settings") )
     {
-        KIPIGalleryExportPlugin::GalleryEdit configDlg(kapp->activeWindow(), mpGallery, i18n("Edit Gallery Data") );
-        configDlg.exec();
+        configDlg = new KIPIGalleryExportPlugin::GalleryEdit(kapp->activeWindow(),
+                                                             mpGallery, i18n("Edit Gallery Data") );
+        configDlg->exec();
     }
-    KIPIGalleryExportPlugin::GalleryWindow dlg(interface, kapp->activeWindow(), mpGallery);
-    dlg.exec();
+
+    dlg = new KIPIGalleryExportPlugin::GalleryWindow(interface, kapp->activeWindow(), mpGallery);
+    dlg->exec();
+
+    delete configDlg;
+    delete dlg;
 }
 
 KIPI::Category Plugin_GalleryExport::category(KAction* action) const
@@ -119,6 +130,6 @@ KIPI::Category Plugin_GalleryExport::category(KAction* action) const
 //     if (action == m_action_configure)
 //         return KIPI::ToolsPlugin;
 //
-    kWarning(51000) << "Unrecognized action for plugin category identification" << endl;
+    kWarning(51000) << "Unrecognized action for plugin category identification";
     return KIPI::ExportPlugin;
 }
