@@ -46,7 +46,7 @@ public:
     virtual KIPI::Category category(KAction* action) const;
     virtual void setup(QWidget* widget);
 
-private slots:
+private Q_SLOTS:
     void slotImageUpload();
 
 private:
