@@ -23,11 +23,11 @@
 
 #define XMD_H
 
-// C++ includes.
+// C++ includes
 
 #include <cstdio>
 
-// C ANSI includes.
+// C ANSI includes
 
 extern "C" 
 {
@@ -36,18 +36,18 @@ extern "C"
 #include <jpeglib.h>
 }
 
-// Qt includes.
+// Qt includes
 
 #include <QFile>
 #include <QFileInfo>
 
-// KDE includes.
+// KDE includes
 
 #include <kprocess.h>
 #include <kdebug.h>
 #include <klocale.h>
 
-// Local includes.
+// Local includes
 
 #include "transupp.h"
 #include "jpegtransform.h"
@@ -139,7 +139,7 @@ bool ImageFlip::flipJPEG(const QString& src, const QString& dest, FlipAction act
         }
         default:
         {
-            qCritical() << "ImageFlip: Nonstandard flip action" << endl;
+            qCritical() << "ImageFlip: Nonstandard flip action";
             err = i18n("Nonstandard flip action");
             return false;
         }
@@ -168,7 +168,7 @@ bool ImageFlip::flipImageMagick(const QString& src, const QString& dest, FlipAct
         }
         default:
         {
-            qCritical() << "ImageFlip: Nonstandard flip action" << endl;
+            qCritical() << "ImageFlip: Nonstandard flip action";
             err = i18n("Nonstandard flip action");
             return false;
         }
@@ -176,7 +176,7 @@ bool ImageFlip::flipImageMagick(const QString& src, const QString& dest, FlipAct
 
     process << src + QString("[0]") << dest;
 
-    kDebug( 51000 ) << "ImageMagick Command line: " << process.program() << endl;
+    kDebug(51000) << "ImageMagick Command line: " << process.program();
 
     process.start();
 
