@@ -80,6 +80,8 @@ bool ImageRotate::rotate(const QString& src, RotateAction angle, QString& err, b
         return false;
     }
 
+    m_tmpFile.setSuffix("kipiplugin-rotate." + fi.suffix());
+
     if ( !m_tmpFile.open() )
     {
         err = i18n("Error in opening temporary file");
@@ -153,7 +155,7 @@ bool ImageRotate::rotateJPEG(const QString& src, const QString& dest, RotateActi
         }
         default:
         {
-            kError( 51000 ) << "ImageRotate: Nonstandard rotation angle" << endl;
+            kError( 51000 ) << "ImageRotate: Nonstandard rotation angle";
             err = i18n("Nonstandard rotation angle");
             return false;
         }
@@ -193,7 +195,7 @@ bool ImageRotate::rotateImageMagick(const QString& src, const QString& dest,
         }
         default:
         {
-            kError( 51000 ) << "ImageRotate: Nonstandard rotation angle" << endl;
+            kError( 51000 ) << "ImageRotate: Nonstandard rotation angle";
             err = i18n("Nonstandard rotation angle");
             return false;
         }
@@ -201,7 +203,7 @@ bool ImageRotate::rotateImageMagick(const QString& src, const QString& dest,
 
     process << src + QString("[0]") << dest;
 
-    kDebug(51000) << "ImageMagick Command line: " << process.program() << endl;
+    kDebug(51000) << "ImageMagick Command line: " << process.program();
 
     process.start();
 
