@@ -23,7 +23,7 @@
 #ifndef EXIF_DEVICE_H
 #define EXIF_DEVICE_H
 
-// Qt includes.
+// Qt includes
 
 #include <QWidget>
 #include <QByteArray>
@@ -45,7 +45,7 @@ public:
     void applyMetadata(QByteArray& exifData);
     void readMetadata(QByteArray& exifData);
 
-signals:
+Q_SIGNALS:
 
     void signalModified();
 
