@@ -138,9 +138,9 @@ QString PicasawebLogin::username() const
 
 void PicasawebLogin::setUsername(const QString& username)
 {
-    kDebug( 51000 )<<" The username passed to me is "<<username <<endl;
+    kDebug(51000)<<" The username passed to me is "<<username ;
     m_nameEdit->setText(username);
-    kDebug( 51000 )<<" The username passed to me is "<<username <<endl;
+    kDebug(51000)<<" The username passed to me is "<<username ;
 }
 
 void PicasawebLogin::setPassword(const QString& password)
