@@ -44,6 +44,7 @@
 #include <QLinkedList>
 #include <QStringList>
 #include <QUrl>
+#include <QPointer>
 
 // KDE includes
 
@@ -133,7 +134,7 @@ void PicasawebTalker::getToken(const QString& username, const QString& password
 
     QString url = "https://www.google.com/accounts/ClientLogin";
 
-    PicasawebLogin *loginDialog = new PicasawebLogin(kapp->activeWindow(), i18n("Login"), username, password);
+    QPointer<PicasawebLogin> loginDialog = new PicasawebLogin(kapp->activeWindow(), i18n("Login"), username, password);
 
     QString username_edit, password_edit;
 
