@@ -72,7 +72,7 @@ public:
 
     void cancel();
 
-signals:
+Q_SIGNALS:
 
     void starting(const ActionData& ad);
     void finished(const ActionData& ad);
