@@ -78,7 +78,7 @@ K_EXPORT_PLUGIN ( RawConverterFactory("kipiplugin_rawconverter") )
 Plugin_RawConverter::Plugin_RawConverter(QObject *parent, const QVariantList &)
                    : KIPI::Plugin( RawConverterFactory::componentData(), parent, "RawConverter")
 {
-    kDebug( 51001 ) << "Plugin_RawConverter plugin loaded";
+    kDebug(51001) << "Plugin_RawConverter plugin loaded";
 }
 
 void Plugin_RawConverter::setup( QWidget* widget )
@@ -108,7 +108,7 @@ void Plugin_RawConverter::setup( QWidget* widget )
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
     if ( !interface )
     {
-           kError( 51000 ) << "Kipi interface is null!" << endl;
+           kError( 51000 ) << "Kipi interface is null!";
            return;
     }
 
@@ -153,7 +153,7 @@ void Plugin_RawConverter::slotActivateSingle()
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
     if (!interface)
     {
-        kError( 51000 ) << "Kipi interface is null!" << endl;
+        kError( 51000 ) << "Kipi interface is null!";
         return;
     }
 
@@ -186,7 +186,7 @@ void Plugin_RawConverter::slotActivateBatch()
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
     if (!interface)
     {
-        kError( 51000 ) << "Kipi interface is null!" << endl;
+        kError( 51000 ) << "Kipi interface is null!";
         return;
     }
 
