@@ -51,7 +51,7 @@ public:
     virtual KIPI::Category category(KAction* action) const;
     virtual void setup(QWidget*);
 
-public slots:
+public Q_SLOTS:
 
     void slotExport();
     void slotImport();
